@@ -30,6 +30,7 @@
 #include <plib/ssg.h>
 
 #include <simgear/math/point3d.hxx>
+#include <simgear/math/sg_geodesy.hxx>
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/scene/model/location.hxx>
 #include <simgear/scene/model/model.hxx>
@@ -49,12 +50,14 @@ const double FGAIBase::lbs_to_slugs = 0.031080950172;   //conversion factor
 
 
 FGAIBase::FGAIBase()
- :  fp( NULL ),
+  : fp( NULL ),
     model( NULL ),
     props( NULL ),
-    manager( NULL )
+    manager( NULL ),
+    _refID( _newAIModelID() )
 {
     _type_str = "model";
+    tgt_heading = tgt_altitude = tgt_speed = 0.0;
     tgt_roll = roll = tgt_pitch = tgt_yaw = tgt_vs = vs = pitch = 0.0;
     bearing = elevation = range = rdot = 0.0;
     x_shift = y_shift = rotation = 0.0;
@@ -69,50 +72,26 @@ FGAIBase::FGAIBase()
 }
 
 FGAIBase::~FGAIBase() {
-    globals->get_scenery()->get_scene_graph()->removeKid(aip.getSceneGraph());
+    // Unregister that one at the scenery manager
+    if (globals->get_scenery()) {
+        globals->get_scenery()->unregister_placement_transform(aip.getTransform());
+        globals->get_scenery()->get_scene_graph()->removeKid(aip.getSceneGraph());
+    }
     // unbind();
     SGPropertyNode *root = globals->get_props()->getNode("ai/models", true);
     root->removeChild(_type_str.c_str(), index);
-    if (fp) delete fp;
+    delete fp;
     fp = NULL;
+    ssgDeRefDelete(model);
+    model = 0;
 }
 
 void FGAIBase::update(double dt) {
+    if (_otype == otStatic) return;
+    if (_otype == otBallistic) CalculateMach();
+
     ft_per_deg_lat = 366468.96 - 3717.12 * cos(pos.lat()*SGD_DEGREES_TO_RADIANS);
     ft_per_deg_lon = 365228.16 * cos(pos.lat()*SGD_DEGREES_TO_RADIANS);
-
-    // Calculate rho at altitude, using standard atmosphere
-    // For the temperature T and the pressure p,
-
-    if (altitude < 36152) {		// curve fits for the troposphere
-      T = 59 - 0.00356 * altitude;
-      p = 2116 * pow( ((T + 459.7) / 518.6) , 5.256);
-
-    } else if ( 36152 < altitude && altitude < 82345 ) {    // lower stratosphere
-      T = -70;
-      p = 473.1 * pow( e , 1.73 - (0.000048 * altitude) );
-
-    } else {                                    //  upper stratosphere
-      T = -205.05 + (0.00164 * altitude);
-      p = 51.97 * pow( ((T + 459.7) / 389.98) , -11.388);
-    }
-
-    rho = p / (1718 * (T + 459.7));
-	
-	// calculate the speed of sound at altitude
-	// a = sqrt ( g * R * (T + 459.7))
-	// where:
-	// a = speed of sound [ft/s]
-	// g = specific heat ratio, which is usually equal to 1.4  
-	// R = specific gas constant, which equals 1716 ft-lb/slug/R 
-	
-	a = sqrt ( 1.4 * 1716 * (T + 459.7));
-	
-	// calculate Mach number
-	
-	Mach = speed/a;
-	
-//	cout  << "Speed(ft/s) "<< speed <<" Altitude(ft) "<< altitude << " Mach " << Mach;
 }
 
 void FGAIBase::Transform() {
@@ -123,7 +102,7 @@ void FGAIBase::Transform() {
       } else {
          aip.setOrientation(roll, pitch, hdg);
       }
-      aip.update( globals->get_scenery()->get_center() );    
+      aip.update();    
     }
 }
 
@@ -136,19 +115,25 @@ bool FGAIBase::init() {
    props = root->getNode(_type_str.c_str(), index, true);
 
    if (model_path != "") {
+    try {
       model = load3DModel( globals->get_fg_root(),
 	                     SGPath(model_path).c_str(),
                              props,
 	                     globals->get_sim_time_sec() );
+    } catch (const sg_exception &e) {
+       model = NULL;
+    }
    }
    if (model) {
      aip.init( model );
      aip.setVisible(true);
      invisible = false;
      globals->get_scenery()->get_scene_graph()->addKid(aip.getSceneGraph());
+     // Register that one at the scenery manager
+     globals->get_scenery()->register_placement_transform(aip.getTransform());
    } else {
      if (model_path != "") { 
-       SG_LOG(SG_INPUT, SG_WARN, "AIBase: Could not load model.");
+       SG_LOG(SG_INPUT, SG_WARN, "AIBase: Could not load model " << model_path);
      }
    } 
 
@@ -175,7 +160,6 @@ ssgBranch * FGAIBase::load3DModel(const string& fg_root,
 			    prop_root,
 			    sim_time_sec);
       manager->setModel(path, model);
-      model->ref();
     }
   //else
   //  {
@@ -184,6 +168,10 @@ ssgBranch * FGAIBase::load3DModel(const string& fg_root,
   //    aip.setVisible(false);
   //    globals->get_scenery()->get_scene_graph()->addKid(aip.getSceneGraph());
   // do some setModel stuff.
+  
+  if (model)
+    model->ref();
+
   return model;
 }
 
@@ -195,7 +183,7 @@ bool FGAIBase::isa( object_type otype ) {
 
 void FGAIBase::bind() {
    props->tie("id", SGRawValueMethods<FGAIBase,int>(*this,
-                                         &FGAIBase::_getID));
+                                         &FGAIBase::getID));
    props->tie("velocities/true-airspeed-kt",  SGRawValuePointer<double>(&speed));
    props->tie("velocities/vertical-speed-fps",
                SGRawValueMethods<FGAIBase,double>(*this,
@@ -347,6 +335,36 @@ double FGAIBase::UpdateRadar(FGAIManager* manager)
    return range_ft2;
 }
 
+Point3D
+FGAIBase::getCartPosAt(const Point3D& off) const
+{
+  // The offset converted to the usual body fixed coordinate system.
+  sgdVec3 sgdOff;
+  sgdSetVec3(sgdOff, -off.x(), off.z(), -off.y());
+
+  // Transform that one to the horizontal local coordinate system.
+  sgdMat4 hlTrans;
+  sgdMakeRotMat4(hlTrans, hdg, pitch, roll);
+  sgdXformPnt3(sgdOff, hlTrans);
+
+  // Now transform to the wgs84 earth centeres system.
+  Point3D pos2(pos.lon()* SGD_DEGREES_TO_RADIANS,
+               pos.lat() * SGD_DEGREES_TO_RADIANS,
+               pos.elev());
+  Point3D cartPos3D = sgGeodToCart(pos2);
+  sgdMat4 ecTrans;
+  sgdMakeCoordMat4(ecTrans, cartPos3D.x(), cartPos3D.y(), cartPos3D.z(),
+                   pos.lon(), 0, - 90 - pos.lat());
+  sgdXformPnt3(sgdOff, ecTrans);
+
+  return Point3D(sgdOff[0], sgdOff[1], sgdOff[2]);
+}
+
+Point3D
+FGAIBase::getGeocPosAt(const Point3D& off) const
+{
+  return sgCartToGeod(getCartPosAt(off));
+}
 
 /*
  * getters and Setters
@@ -385,6 +403,48 @@ bool FGAIBase::_isNight() {
     return (fgGetFloat("/sim/time/sun-angle-rad") > 1.57);
 }
 
-int FGAIBase::_getID() const {
-    return (int)(this);
+int FGAIBase::getID() const {
+    return  _refID;
 }
+
+void FGAIBase::CalculateMach() {
+     // Calculate rho at altitude, using standard atmosphere
+     // For the temperature T and the pressure p,
+ 
+     if (altitude < 36152) {		// curve fits for the troposphere
+       T = 59 - 0.00356 * altitude;
+       p = 2116 * pow( ((T + 459.7) / 518.6) , 5.256);
+ 
+     } else if ( 36152 < altitude && altitude < 82345 ) {    // lower stratosphere
+       T = -70;
+       p = 473.1 * pow( e , 1.73 - (0.000048 * altitude) );
+ 
+     } else {                                    //  upper stratosphere
+       T = -205.05 + (0.00164 * altitude);
+       p = 51.97 * pow( ((T + 459.7) / 389.98) , -11.388);
+     }
+ 
+     rho = p / (1718 * (T + 459.7));
+ 	
+ 	// calculate the speed of sound at altitude
+ 	// a = sqrt ( g * R * (T + 459.7))
+ 	// where:
+ 	// a = speed of sound [ft/s]
+ 	// g = specific heat ratio, which is usually equal to 1.4  
+ 	// R = specific gas constant, which equals 1716 ft-lb/slug/R 
+ 	
+ 	a = sqrt ( 1.4 * 1716 * (T + 459.7));
+ 	
+ 	// calculate Mach number
+ 	
+ 	Mach = speed/a;
+ 	
+ //	cout  << "Speed(ft/s) "<< speed <<" Altitude(ft) "<< altitude << " Mach " << Mach;
+}
+
+int FGAIBase::_newAIModelID() {
+   static int id = 0;
+   if (!++id) id++;	// id = 0 is not allowed.
+   return id;
+}
+
