@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: aircraft.cxx,v 1.12 2004/11/19 22:10:42 curt Exp $
+// $Id: aircraft.cxx,v 1.13 2005/02/22 18:56:13 ehofman Exp $
 
 
 #include <stdio.h>
@@ -159,7 +159,7 @@ fgLoadAircraft (const SGPropertyNode * arg)
     globals->restoreInitialState();
 
     fgSetString("/sim/aircraft", aircraft.c_str());
-    fgSetString("/sim/panel/path", "Aircraft/c172/Panels/c172-vfr-panel.xml");
+    fgSetString("/sim/panel/path", "Aircraft/c172p/Panels/c172-vfr-panel.xml");
 
     if ( aircraft.size() > 0 ) {
         SGPath aircraft_path(globals->get_fg_root());
@@ -183,7 +183,7 @@ fgLoadAircraft (const SGPropertyNode * arg)
     // Initialize the (new) 2D panel.
     //
     string panel_path = fgGetString("/sim/panel/path",
-                                    "Aircraft/c172/Panels/c172-vfr-panel.xml");
+                                    "Aircraft/c172p/Panels/c172-vfr-panel.xml");
 
     FGPanel *panel = fgReadPanel(panel_path);
     if (panel == 0) {
