@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: ExternalNet.cxx,v 1.13 2004/11/19 22:10:42 curt Exp $
+// $Id: ExternalNet.cxx,v 1.14 2005/08/14 12:57:13 ehofman Exp $
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -102,7 +102,7 @@ void FGExternalNet::init() {
     double lon = fgGetDouble( "/sim/presets/longitude-deg" );
     double lat = fgGetDouble( "/sim/presets/latitude-deg" );
     double alt = fgGetDouble( "/sim/presets/altitude-ft" );
-    double ground = fgGetDouble( "/environment/ground-elevation-m" );
+    double ground = get_Runway_altitude_m();
     double heading = fgGetDouble("/sim/presets/heading-deg");
     double speed = fgGetDouble( "/sim/presets/airspeed-kt" );
 
