@@ -44,7 +44,9 @@ INCLUDES
 #include "FGTrim.h"
 #include "FGInitialCondition.h"
 #include "FGJSBBase.h"
+#include "FGGroundCallback.h"
 #include "FGPropertyManager.h"
+#include "FGPropagate.h"
 
 #include <vector>
 
@@ -52,7 +54,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_FDMEXEC "$Id: FGFDMExec.h,v 1.7 2004/06/27 19:35:54 ehofman Exp $"
+#define ID_FDMEXEC "$Id: FGFDMExec.h,v 1.8 2005/05/22 08:06:47 ehofman Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -98,7 +100,7 @@ CLASS DOCUMENTATION
        a message is printed out when they go out of bounds
 
     @author Jon S. Berndt
-    @version $Id: FGFDMExec.h,v 1.7 2004/06/27 19:35:54 ehofman Exp $
+    @version $Id: FGFDMExec.h,v 1.8 2005/05/22 08:06:47 ehofman Exp $
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -142,6 +144,8 @@ public:
   /// Resumes the sim
   void Resume(void) {frozen = false;}
 
+  void SetGroundCallback(FGGroundCallback*);
+
   /** Loads an aircraft model.
       @param AircraftPath path to the aircraft directory. For instance:
       "aircraft". Under aircraft, then, would be directories for various
@@ -200,6 +204,8 @@ public:
   inline FGAtmosphere* GetAtmosphere(void)    {return Atmosphere;}
   /// Returns the FGFCS pointer.
   inline FGFCS* GetFCS(void)                  {return FCS;}
+  /// Returns the FGGroundCallback pointer.
+  inline FGGroundCallback* GetGroundCallback(void) {return GroundCallback;}
   /// Returns the FGPropulsion pointer.
   inline FGPropulsion* GetPropulsion(void)    {return Propulsion;}
   /// Returns the FGAircraft pointer.
@@ -213,7 +219,7 @@ public:
   /// Returns the FGAircraft pointer.
   inline FGAircraft* GetAircraft(void)        {return Aircraft;}
   /// Returns the FGPropagate pointer.
-  inline FGPropagate* GetPropagate(void)        {return Propagate;}
+  inline FGPropagate* GetPropagate(void)      {return Propagate;}
   /// Returns the FGAuxiliary pointer.
   inline FGAuxiliary* GetAuxiliary(void)      {return Auxiliary;}
   /// Returns the FGOutput pointer.
@@ -281,6 +287,7 @@ private:
   FGState*           State;
   FGAtmosphere*      Atmosphere;
   FGFCS*             FCS;
+  FGGroundCallback*  GroundCallback;
   FGPropulsion*      Propulsion;
   FGMassBalance*     MassBalance;
   FGAerodynamics*    Aerodynamics;
