@@ -64,7 +64,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_MATRIX33 "$Id: FGMatrix33.h,v 1.7 2004/03/14 14:57:07 ehofman Exp $"
+#define ID_MATRIX33 "$Id: FGMatrix33.h,v 1.8 2004/12/16 12:47:20 ehofman Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -113,17 +113,12 @@ public:
   };
 
   /** Default initializer.
-
-      Create a zero matrix.
-   */
+      Create a zero matrix.  */
   FGMatrix33(void);
 
   /** Copy constructor.
-
       @param M Matrix which is used for initialization.
-
-      Create copy of the matrix given in the argument.
-   */
+      Create copy of the matrix given in the argument.  */
   FGMatrix33(const FGMatrix33& M) {
     Entry(1,1) = M.Entry(1,1);
     Entry(2,1) = M.Entry(2,1);
@@ -139,7 +134,6 @@ public:
   }
 
   /** Initialization by given values.
-
       @param m11 value of the 1,1 Matrix element.
       @param m12 value of the 1,2 Matrix element.
       @param m13 value of the 1,3 Matrix element.
@@ -149,9 +143,7 @@ public:
       @param m31 value of the 3,1 Matrix element.
       @param m32 value of the 3,2 Matrix element.
       @param m33 value of the 3,3 Matrix element.
-
-      Create a matrix from the doubles given in the arguments.
-   */
+      Create a matrix from the doubles given in the arguments.   */
   FGMatrix33(double m11, double m12, double m13,
              double m21, double m22, double m23,
              double m31, double m32, double m33) {
@@ -168,30 +160,24 @@ public:
     Debug(0);
   }
 
-  /** Destructor.
-   */
+  /// Destructor.
   ~FGMatrix33(void) { Debug(1); }
 
   /** Read access the entries of the matrix.
       @param row Row index.
       @param col Column index.
-
       @return the value of the matrix entry at the given row and
-      column indices. Indices are counted starting with 1.
-   */
+      column indices. Indices are counted starting with 1.   */
   double operator()(unsigned int row, unsigned int col) const {
     return Entry(row, col);
   }
 
   /** Write access the entries of the matrix.
       Note that the indices given in the arguments are unchecked.
-
       @param row Row index.
       @param col Column index.
-
       @return a reference to the matrix entry at the given row and
-      column indices. Indices are counted starting with 1.
-   */
+      column indices. Indices are counted starting with 1.   */
   double& operator()(unsigned int row, unsigned int col) {
     return Entry(row, col);
   }
@@ -200,15 +186,11 @@ public:
       This function is just a shortcut for the @ref double&
       operator()(unsigned int row, unsigned int col) function. It is
       used internally to access the elements in a more convenient way.
-
       Note that the indices given in the arguments are unchecked.
-
       @param row Row index.
       @param col Column index.
-
       @return the value of the matrix entry at the given row and
-      column indices. Indices are counted starting with 1.
-   */
+      column indices. Indices are counted starting with 1.   */
   double Entry(unsigned int row, unsigned int col) const {
     return data[(col-1)*eRows+row-1];
   }
@@ -217,34 +199,27 @@ public:
       This function is just a shortcut for the @ref double&
       operator()(unsigned int row, unsigned int col) function. It is
       used internally to access the elements in a more convenient way.
-
       Note that the indices given in the arguments are unchecked.
-
       @param row Row index.
       @param col Column index.
-
       @return a reference to the matrix entry at the given row and
-      column indices. Indices are counted starting with 1.
-   */
+      column indices. Indices are counted starting with 1.   */
    double& Entry(unsigned int row, unsigned int col) {
      return data[(col-1)*eRows+row-1];
    }
 
   /** Number of rows in the matrix.
-      @return the number of rows in the matrix.
-   */
+      @return the number of rows in the matrix.   */
    unsigned int Rows(void) const { return eRows; }
 
   /** Number of cloumns in the matrix.
-      @return the number of columns in the matrix.
-   */
+      @return the number of columns in the matrix.   */
    unsigned int Cols(void) const { return eColumns; }
 
   /** Transposed matrix.
       This function only returns the transpose of this matrix. This matrix itself
       remains unchanged.
-      @return the transposed matrix.
-   */
+      @return the transposed matrix.   */
   FGMatrix33 Transposed(void) const {
     return FGMatrix33( Entry(1,1), Entry(2,1), Entry(3,1),
                        Entry(1,2), Entry(2,2), Entry(3,2),
@@ -252,18 +227,15 @@ public:
   }
 
   /** Transposes this matrix.
-      This function only transposes this matrix. Nothing is returned.
-   */
+      This function only transposes this matrix. Nothing is returned.   */
   void T(void);
 
 /** Initialize the matrix.
-    This function initializes a matrix to all 0.0.
- */
+    This function initializes a matrix to all 0.0. */
   void InitMatrix(void);
 
 /** Initialize the matrix.
-    This function initializes a matrix to user specified values.
- */
+    This function initializes a matrix to user specified values. */
   void InitMatrix(double m11, double m12, double m13,
                   double m21, double m22, double m23,
                   double m31, double m32, double m33) {
@@ -279,8 +251,7 @@ public:
   }
 
   /** Determinant of the matrix.
-      @return the determinant of the matrix.
-   */
+      @return the determinant of the matrix.   */
   double Determinant(void) const;
 
   /** Return if the matrix is invertible.
@@ -288,24 +259,19 @@ public:
       invertible. This is done by simply computing the determinant and
       check if it is zero. Note that this test does not cover any
       instabilities caused by nearly singular matirces using finite
-      arithmetics. It only checks exact singularity.
-   */
+      arithmetics. It only checks exact singularity.   */
   bool Invertible(void) const { return 0.0 != Determinant(); }
 
   /** Return the inverse of the matrix.
       Computes and returns if the inverse of the matrix. It is computed
       by Cramers Rule. Also there are no checks performed if the matrix
       is invertible. If you are not sure that it really is check this
-      with the @ref Invertible() call before.
-   */
+      with the @ref Invertible() call before.   */
   FGMatrix33 Inverse(void) const;
 
   /** Assignment operator.
-
       @param A source matrix.
-
-      Copy the content of the matrix given in the argument into *this.
-   */
+      Copy the content of the matrix given in the argument into *this.   */
   FGMatrix33& operator=(const FGMatrix33& A) {
     data[0] = A.data[0];
     data[1] = A.data[1];
@@ -320,113 +286,80 @@ public:
   }
 
   /** Matrix vector multiplication.
-
       @param v vector to multiply with.
       @return matric vector product.
-
       Compute and return the product of the current matrix with the
-      vector given in the argument.
-   */
+      vector given in the argument.   */
   FGColumnVector3 operator*(const FGColumnVector3& v) const;
 
   /** Matrix subtraction.
-
       @param B matrix to add to.
       @return difference of the matrices.
-
       Compute and return the sum of the current matrix and the matrix
-      B given in the argument.
-  */
+      B given in the argument.  */
   FGMatrix33 operator-(const FGMatrix33& B) const;
 
   /** Matrix addition.
-
       @param B matrix to add to.
       @return sum of the matrices.
-
       Compute and return the sum of the current matrix and the matrix
-      B given in the argument.
-  */
+      B given in the argument.  */
   FGMatrix33 operator+(const FGMatrix33& B) const;
 
   /** Matrix product.
-
       @param B matrix to add to.
       @return product of the matrices.
-
       Compute and return the product of the current matrix and the matrix
-      B given in the argument.
-  */
+      B given in the argument.  */
   FGMatrix33 operator*(const FGMatrix33& B) const;
 
   /** Multiply the matrix with a scalar.
-
       @param scalar scalar factor to multiply with.
       @return scaled matrix.
-
       Compute and return the product of the current matrix with the
-      scalar value scalar given in the argument.
-  */
+      scalar value scalar given in the argument.  */
   FGMatrix33 operator*(const double scalar) const;
 
   /** Multiply the matrix with 1.0/scalar.
-
       @param scalar scalar factor to divide through.
       @return scaled matrix.
-
       Compute and return the product of the current matrix with the
-      scalar value 1.0/scalar, where scalar is given in the argument.
-  */
+      scalar value 1.0/scalar, where scalar is given in the argument.  */
   FGMatrix33 operator/(const double scalar) const;
 
   /** In place matrix subtraction.
-
       @param B matrix to subtract.
       @return reference to the current matrix.
-
       Compute the diffence from the current matrix and the matrix B
-      given in the argument.
-  */
+      given in the argument.  */
   FGMatrix33& operator-=(const FGMatrix33 &B);
 
   /** In place matrix addition.
-
       @param B matrix to add.
       @return reference to the current matrix.
-
       Compute the sum of the current matrix and the matrix B
-      given in the argument.
-  */
+      given in the argument.  */
   FGMatrix33& operator+=(const FGMatrix33 &B);
 
   /** In place matrix multiplication.
-
       @param B matrix to multiply with.
       @return reference to the current matrix.
-
       Compute the product of the current matrix and the matrix B
-      given in the argument.
-  */
+      given in the argument.  */
   FGMatrix33& operator*=(const FGMatrix33 &B);
 
   /** In place matrix scale.
-
       @param scalar scalar value to multiply with.
       @return reference to the current matrix.
-
       Compute the product of the current matrix and the scalar value scalar
-      given in the argument.
-  */
+      given in the argument.  */
   FGMatrix33& operator*=(const double scalar);
 
   /** In place matrix scale.
-
       @param scalar scalar value to divide through.
       @return reference to the current matrix.
-
       Compute the product of the current matrix and the scalar value
-      1.0/scalar, where scalar is given in the argument.
-  */
+      1.0/scalar, where scalar is given in the argument.  */
   FGMatrix33& operator/=(const double scalar);
 
 private:
@@ -436,33 +369,24 @@ private:
 };
 
 /** Scalar multiplication.
-
     @param scalar scalar value to multiply with.
     @param A Matrix to multiply.
-
-    Multiply the Matrix with a scalar value.
-*/
+    Multiply the Matrix with a scalar value.*/
 inline FGMatrix33 operator*(double scalar, const FGMatrix33& A) {
   // use already defined operation.
   return A*scalar;
 }
 
 /** Write matrix to a stream.
-
     @param os Stream to write to.
     @param M Matrix to write.
-
-    Write the matrix to a stream.
-*/
+    Write the matrix to a stream.*/
 ostream& operator<<(ostream& os, const FGMatrix33& M);
 
 /** Read matrix from a stream.
-
     @param os Stream to read from.
     @param M Matrix to initialize with the values from the stream.
-
-    Read matrix from a stream.
-*/
+    Read matrix from a stream.*/
 istream& operator>>(istream& is, FGMatrix33& M);
 
 } // namespace JSBSim
