@@ -48,7 +48,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_PROPAGATE "$Id: FGPropagate.h,v 1.2 2004/09/11 12:41:05 ehofman Exp $"
+#define ID_PROPAGATE "$Id: FGPropagate.h,v 1.3 2005/05/22 08:06:47 ehofman Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -62,7 +62,7 @@ CLASS DOCUMENTATION
 
 /** Models the EOM and integration/propagation of state
     @author Jon S. Berndt, Mathias Froehlich
-    @version $Id: FGPropagate.h,v 1.2 2004/09/11 12:41:05 ehofman Exp $
+    @version $Id: FGPropagate.h,v 1.3 2005/05/22 08:06:47 ehofman Exp $
   */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -116,9 +116,9 @@ public:
       zero if JSBSim is running in standalone mode.
       @return distance of the runway from the center of the earth.
       @units feet */
-  double GetRunwayRadius(void) const { return RunwayRadius; }
+  double GetRunwayRadius(void) const;
   double GetSeaLevelRadius(void) const { return SeaLevelRadius; }
-  double GetDistanceAGL(void)  const { return VState.vLocation.GetRadius()-RunwayRadius; }
+  double GetDistanceAGL(void)  const;
   double GetRadius(void) const { return VState.vLocation.GetRadius(); }
   double GetLongitude(void) const { return VState.vLocation.GetLongitude(); }
   double GetLatitude(void) const { return VState.vLocation.GetLatitude(); }
@@ -139,11 +139,12 @@ public:
   void SetRadius(double r) { VState.vLocation.SetRadius(r); }
   void SetLocation(const FGLocation& l) { VState.vLocation = l; }
   void Seth(double tt);
-  void SetRunwayRadius(double tt) { RunwayRadius = tt; }
   void SetSeaLevelRadius(double tt) { SeaLevelRadius = tt; }
   void SetDistanceAGL(double tt);
   void SetInitialState(const FGInitialCondition *);
 
+  void RecomputeRunwayRadius(void);
+
   void bind(void);
   void unbind(void);
 
