@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: LaRCsim.cxx,v 1.11 2004/11/19 22:10:42 curt Exp $
+// $Id: LaRCsim.cxx,v 1.13 2005/11/01 13:41:50 ehofman Exp $
 
 #include <math.h>
 #include <string.h>		// strcmp()
@@ -29,7 +29,7 @@
 #include <simgear/scene/model/placement.hxx>
 
 #include <Aircraft/aircraft.hxx>
-#include <Controls/controls.hxx>
+#include <Aircraft/controls.hxx>
 #include <FDM/flight.hxx>
 #include <FDM/UIUCModel/uiuc_aircraft.h>
 #include <Main/fg_props.hxx>
@@ -285,8 +285,10 @@ void FGLaRCsim::update( double dt ) {
     Brake_pct[1] = globals->get_controls()->get_brake_left();
 
     // Inform LaRCsim of the local terrain altitude
-    // Runway_altitude = get_Runway_altitude();
-    Runway_altitude = fgGetDouble("/position/ground-elev-m") * SG_METER_TO_FEET;
+    Runway_altitude
+      = get_groundlevel_m(Latitude, Longitude, Altitude * SG_FEET_TO_METER)
+      * SG_METER_TO_FEET;
+
     // Weather
     /* V_north_airmass = get_V_north_airmass();
        V_east_airmass =  get_V_east_airmass();
