@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: ls_interface.c,v 1.6 2002/01/30 15:17:27 david Exp $
+ * $Id: ls_interface.c,v 1.1.1.1 2002/09/10 01:14:02 curt Exp $
  * (Log is kept at end of this file)
  **************************************************************************/
 
@@ -90,7 +90,7 @@
 		routine ls_pause(); and added call to exit() on termination.
 
 
-$Header: /var/cvs/FlightGear-0.7/FlightGear/src/FDM/LaRCsim/ls_interface.c,v 1.6 2002/01/30 15:17:27 david Exp $
+$Header: /var/cvs/FlightGear-0.9/FlightGear/src/FDM/LaRCsim/ls_interface.c,v 1.1.1.1 2002/09/10 01:14:02 curt Exp $
 $Original log: LaRCsim.c,v $
  * Revision 1.4.1.7  1995/04/07  01:04:37  bjax
  * Many changes made to support storage of sim options from run to run,
@@ -280,9 +280,9 @@ static char  matname[MAX_FILE_NAME_LENGTH]  = "run.m";
 
 
 void ls_stamp( void ) {
-    char rcsid[] = "$Id: ls_interface.c,v 1.6 2002/01/30 15:17:27 david Exp $";
-    char revid[] = "$Revision: 1.6 $";
-    char dateid[] = "$Date: 2002/01/30 15:17:27 $";
+    char rcsid[] = "$Id: ls_interface.c,v 1.1.1.1 2002/09/10 01:14:02 curt Exp $";
+    char revid[] = "$Revision: 1.1.1.1 $";
+    char dateid[] = "$Date: 2002/09/10 01:14:02 $";
     struct tm *nowtime;
     time_t nowtime_t;
     long date;
@@ -580,6 +580,9 @@ int ls_ForceAltitude(double alt_feet) {
 /* Flight Gear Modification Log
  *
  * $Log: ls_interface.c,v $
+ * Revision 1.1.1.1  2002/09/10 01:14:02  curt
+ * Initial revision of FlightGear-0.9.0
+ *
  * Revision 1.6  2002/01/30 15:17:27  david
  * Fixes from Cameron Moore:
  *
