@@ -19,8 +19,12 @@ public:
     float getMP();
     float getEGT();
     float getMaxPower(); // max sea-level power
+    float getBoost() { return _boostPressure; }
+    float getOilTemp() { return _oilTemp; }
 
     virtual void calc(float pressure, float temp, float speed);
+    virtual void stabilize();
+    virtual void integrate(float dt);
     virtual float getTorque();
     virtual float getFuelFlow();
 
@@ -41,6 +45,10 @@ private:
     float _torque;
     float _fuelFlow;
     float _egt;
+    float _boostPressure;
+    float _oilTemp;
+    float _oilTempTarget;
+    float _dOilTempdt;
 };
 
 }; // namespace yasim
