@@ -18,8 +18,8 @@ AirportList::AirportList (int x, int y, int width, int height)
     for (int i = 0; i < _nAirports; i++) {
         const FGAirport *airport = _airports->getAirport(i);
         snprintf(buf, 1023, "%s  %s",
-                 airport->_id.c_str(),
-                 airport->_name.c_str());
+                 airport->getId().c_str(),
+                 airport->getName().c_str());
 
         unsigned int buf_len = (strlen(buf) > 1023) ? 1023 : strlen(buf);
         
@@ -41,9 +41,9 @@ AirportList::~AirportList ()
 }
 
 char *
-AirportList::getStringValue ()
+AirportList::getListStringValue ()
 {
-    return (char *)_airports->getAirport(getIntegerValue())->_id.c_str();
+    return (char *)_airports->getAirport(getListIntegerValue())->getId().c_str();
 }
 
 // end of AirportList.cxx
