@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gui.cxx,v 1.19 2004/05/12 15:36:07 andy Exp $
+ * $Id: gui.cxx,v 1.20 2005/10/20 13:05:02 mfranz Exp $
  **************************************************************************/
 
 
@@ -51,10 +51,6 @@
 #include "preset_dlg.hxx"
 #include "layout.hxx"
 
-extern void initDialog (void);
-extern void mkDialogInit (void);
-extern void ConfirmExitDialogInit(void);
-
 
 puFont guiFnt = 0;
 fntTexFont *guiFntHandle = 0;
@@ -74,8 +70,6 @@ void guiInit()
     puSetDefaultStyle         ( PUSTYLE_SMALL_SHADED ); //PUSTYLE_DEFAULT
     puSetDefaultColourScheme  (0.8, 0.8, 0.9, 1);
 
-    initDialog();
-
     // Next check home directory
     SGPath fntpath;
     char* envp = ::getenv( "FG_FONTS" );
@@ -124,8 +118,5 @@ void guiInit()
 	initMouseQuat();
 
     // Set up our Dialog Boxes
-    ConfirmExitDialogInit();
     fgPresetInit();
-	
-    mkDialogInit();
 }
