@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gui.h,v 1.11 2004/10/06 03:29:14 curt Exp $
+ * $Id: gui.h,v 1.12 2005/10/20 13:05:02 mfranz Exp $
  **************************************************************************/
 
 
@@ -45,7 +45,6 @@ extern void guiInit();
 extern void mkDialog(const char *txt);
 extern void guiErrorMessage(const char *txt);
 extern void guiErrorMessage(const char *txt, const sg_throwable &throwable);
-extern void ConfirmExitDialog(void);
 
 extern void fgDumpSnapShot();
 
@@ -65,7 +64,6 @@ extern void fgHiResDump();
 #if defined( WIN32 ) && !defined( __CYGWIN__) && !defined(__MINGW32__)
 extern void printScreen(puObject *);
 #endif
-extern void MayBeGoodBye(puObject *);
 extern void guiTogglePanel(puObject *);
 extern void PilotOffsetAdjust(puObject *);
 extern void fgHUDalphaAdjust(puObject *);
