@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gui_funcs.cxx,v 1.28 2004/12/29 20:38:17 curt Exp $
+ * $Id: gui_funcs.cxx,v 1.37 2005/11/12 11:40:57 mfranz Exp $
  **************************************************************************/
 
 
@@ -69,17 +69,19 @@
 
 #include <Include/general.hxx>
 #include <Aircraft/aircraft.hxx>
+#include <Aircraft/controls.hxx>
 #include <Airports/simple.hxx>
 #include <Autopilot/auto_gui.hxx>
 #include <Cockpit/panel.hxx>
-#include <Controls/controls.hxx>
 #include <FDM/flight.hxx>
 #include <Main/main.hxx>
 #include <Main/fg_init.hxx>
 #include <Main/fg_io.hxx>
 #include <Main/globals.hxx>
 #include <Main/fg_props.hxx>
+#include <Main/renderer.hxx>
 #include <Main/viewmgr.hxx>
+#include <GUI/new_gui.hxx>
 
 #if defined( WIN32 ) && !defined( __CYGWIN__ ) && !defined(__MINGW32__)
 #  include <simgear/screen/win32-printer.h>
@@ -95,8 +97,6 @@
 SG_USING_STD(string);
 SG_USING_STD(cout);
 
-extern void fgHUDalphaAdjust( puObject * );
-
 // from cockpit.cxx
 extern void fgLatLonFormatToggle( puObject *);
 
@@ -106,36 +106,18 @@ extern void fgUpdateHUD( GLfloat x_start, GLfloat y_start,
                          GLfloat x_end, GLfloat y_end );
 #endif
 
-puDialogBox  *dialogBox = 0;
-puFrame      *dialogFrame = 0;
-puText       *dialogBoxMessage = 0;
-puOneShot    *dialogBoxOkButton = 0;
 
-puDialogBox  *YNdialogBox = 0;
-puFrame      *YNdialogFrame = 0;
-puText       *YNdialogBoxMessage = 0;
-puOneShot    *YNdialogBoxOkButton = 0;
-puOneShot    *YNdialogBoxNoButton = 0;
+// TODO: remove after the last hardcoded dialog has died
+char *gui_msg_OK     = "OK";
+char *gui_msg_NO     = "NO";
+char *gui_msg_YES    = "YES";
+char *gui_msg_CANCEL = "CANCEL";
+char *gui_msg_RESET  = "RESET";
 
-char *gui_msg_OK;     // "OK"
-char *gui_msg_NO;     // "NO"
-char *gui_msg_YES;    // "YES"
-char *gui_msg_CANCEL; // "CANCEL"
-char *gui_msg_RESET;  // "RESET"
-
-char msg_OK[]     = "OK";
-char msg_NO[]     = "NO";
-char msg_YES[]    = "YES";
-char msg_CANCEL[] = "Cancel";
-char msg_RESET[]  = "Reset";
-
-char global_dialog_string[256];
 
 const __fg_gui_fn_t __fg_gui_fn[] = {
 
         // File
-        {"saveFlight", saveFlight},
-        {"loadFlight", loadFlight},
         {"reInit", reInit},
 #ifdef TR_HIRES_SNAP
         {"dumpHiResSnapShot", fgHiResDumpWrapper},
@@ -144,12 +126,9 @@ const __fg_gui_fn_t __fg_gui_fn[] = {
 #if defined( WIN32 ) && !defined( __CYGWIN__) && !defined(__MINGW32__)
         {"printScreen", printScreen},
 #endif
-        {"MayBeGoodBye", MayBeGoodBye},
 
         //View
         {"guiTogglePanel", guiTogglePanel},
-        {"PilotOffsetAdjust", PilotOffsetAdjust},
-        {"fgHUDalphaAdjust", fgHUDalphaAdjust},
         {"prop_pickerView", prop_pickerView},
 
         // Environment
@@ -179,29 +158,26 @@ const __fg_gui_fn_t __fg_gui_fn[] = {
 
 /* ================ General Purpose Functions ================ */
 
-void initDialog(void) {
-    // Initialize our GLOBAL GUI STRINGS
-    gui_msg_OK     = msg_OK;     // "OK"
-    gui_msg_NO     = msg_NO;     // "NO"
-    gui_msg_YES    = msg_YES;    // "YES"
-    gui_msg_CANCEL = msg_CANCEL; // "CANCEL"
-    gui_msg_RESET  = msg_RESET;  // "RESET"
-}
-
 // General Purpose Message Box
 void mkDialog (const char *txt)
 {
-    strncpy(global_dialog_string, txt, 256);
-    dialogBoxMessage->setLabel(global_dialog_string);
-    FG_PUSH_PUI_DIALOG( dialogBox );
+    NewGUI *gui = (NewGUI *)globals->get_subsystem("gui");
+    if (!gui)
+        return;
+    SGPropertyNode_ptr dlg = gui->getDialog("message");
+    if (!dlg)
+        return;
+
+    dlg->setStringValue("text/label", txt);
+    dlg->setStringValue("button/legend", "OK");
+    gui->showDialog("message");
 }
 
 // Message Box to report an error.
 void guiErrorMessage (const char *txt)
 {
     SG_LOG(SG_GENERAL, SG_ALERT, txt);
-    if (dialogBox != 0)
-      mkDialog(txt);
+    mkDialog(txt);
 }
 
 // Message Box to report a throwable (usually an exception).
@@ -216,14 +192,7 @@ void guiErrorMessage (const char *txt, const sg_throwable &throwable)
       msg += ')';
     }
     SG_LOG(SG_GENERAL, SG_ALERT, msg);
-    if (dialogBox != 0)
-      mkDialog(msg.c_str());
-}
-
-// Intercept the Escape Key
-void ConfirmExitDialog(void)
-{
-    FG_PUSH_PUI_DIALOG( YNdialogBox );
+    mkDialog(msg.c_str());
 }
 
 
@@ -237,135 +206,6 @@ ____________________________________________________________________*/
 // Added by David Findlay <nedz@bigpond.com>
 // on Sunday 3rd of December
 
-// Start new Save Dialog Box
-puDialogBox     *SaveDialog = 0;
-puFrame         *SaveDialogFrame = 0;
-puText          *SaveDialogMessage = 0;
-puInput         *SaveDialogInput = 0;
-
-puOneShot       *SaveDialogOkButton = 0;
-puOneShot       *SaveDialogCancelButton = 0;
-// static puOneShot       *SaveDialogResetButton = 0;
-
-// Default save filename
-char saveFile[256] = "fgfs.sav";
-
-// Cancel Button
-void SaveDialogCancel(puObject *) {
-    FG_POP_PUI_DIALOG( SaveDialog );
-}
-
-// If press OK do this
-void SaveDialogOk(puObject*) {
-
-    FG_POP_PUI_DIALOG( SaveDialog );
-
-    char *s;
-    SaveDialogInput->getValue(&s);
-
-    ofstream output(s);
-    // cout << saveFile << endl;
-    if (output.good() && fgSaveFlight(output)) {
-	output.close();
-	mkDialog("Saved flight");
-	SG_LOG(SG_INPUT, SG_INFO, "Saved flight");
-    } else {
-	mkDialog("Cannot save flight");
-	SG_LOG(SG_INPUT, SG_ALERT, "Cannot save flight");
-    }
-}
-
-// Create Dialog
-void saveFlight(puObject *cv) {
-    SaveDialog = new puDialogBox (150, 50);
-    {
-        SaveDialogFrame   = new puFrame           (0,0,350, 150);
-        SaveDialogMessage
-            = new puText( (150 - puGetDefaultLabelFont().getStringWidth( "File Name:" ) / 2), 110 );
-        SaveDialogMessage ->    setLabel          ("File Name:");
-
-        SaveDialogInput   = new puInput           (50, 70, 300, 100);
-        SaveDialogInput   ->    setValue          (saveFile);
-        SaveDialogInput   ->    acceptInput();
-
-        SaveDialogOkButton     =  new puOneShot   (50, 10, 110, 50);
-        SaveDialogOkButton     ->     setLegend   (gui_msg_OK);
-        SaveDialogOkButton     ->     setCallback ( SaveDialogOk );
-        SaveDialogOkButton     ->     makeReturnDefault(TRUE);
-
-        SaveDialogCancelButton =  new puOneShot   (140, 10, 210, 50);
-        SaveDialogCancelButton ->     setLegend   (gui_msg_CANCEL);
-        SaveDialogCancelButton ->     setCallback ( SaveDialogCancel );
-    }
-    FG_FINALIZE_PUI_DIALOG( SaveDialog );
-   
-    SaveDialog -> reveal();
-}
-
-// Load Dialog Start
-puDialogBox     *LoadDialog = 0;
-puFrame         *LoadDialogFrame = 0;
-puText          *LoadDialogMessage = 0;
-puInput         *LoadDialogInput = 0;
-
-puOneShot       *LoadDialogOkButton = 0;
-puOneShot       *LoadDialogCancelButton = 0;
-// static puOneShot       *LoadDialogResetButton = 0;
-
-// Default load filename
-char loadFile[256] = "fgfs.sav";
-
-// Do this if the person click okay
-void LoadDialogOk(puObject *) {
-
-    FG_POP_PUI_DIALOG( LoadDialog );
-
-    char *l;
-    LoadDialogInput->getValue(&l);
-
-    ifstream input(l);
-    if (input.good() && fgLoadFlight(input)) {
-	input.close();
-	mkDialog("Loaded flight");
-	SG_LOG(SG_INPUT, SG_INFO, "Restored flight");
-    } else {
-	mkDialog("Failed to load flight");
-	SG_LOG(SG_INPUT, SG_ALERT, "Cannot load flight");
-    }
-}
-
-// Do this if the person presses cancel
-void LoadDialogCancel(puObject *) {
-    FG_POP_PUI_DIALOG( LoadDialog );
-}
-
-// Create Load Dialog
-void loadFlight(puObject *cb)
-{
-    LoadDialog = new puDialogBox (150, 50);
-    {
-        LoadDialogFrame   = new puFrame           (0,0,350, 150);
-        LoadDialogMessage
-            = new puText( (150 - puGetDefaultLabelFont().getStringWidth( "File Name:" ) / 2), 110 );
-        LoadDialogMessage ->    setLabel          ("File Name:");
-
-        LoadDialogInput   = new puInput           (50, 70, 300, 100);
-        LoadDialogInput   ->    setValue          (loadFile);
-        LoadDialogInput   ->    acceptInput();
-
-        LoadDialogOkButton     =  new puOneShot   (50, 10, 110, 50);
-        LoadDialogOkButton     ->     setLegend   (gui_msg_OK);
-        LoadDialogOkButton     ->     setCallback ( LoadDialogOk );
-        LoadDialogOkButton     ->     makeReturnDefault(TRUE);
-
-        LoadDialogCancelButton =  new puOneShot   (140, 10, 210, 50);
-        LoadDialogCancelButton ->     setLegend   (gui_msg_CANCEL);
-        LoadDialogCancelButton ->     setCallback ( LoadDialogCancel );
-    }
-    FG_FINALIZE_PUI_DIALOG( LoadDialog );
-   
-    LoadDialog -> reveal();
-}
 
 // This is the accessor function
 void guiTogglePanel(puObject *cb)
@@ -379,86 +219,6 @@ void guiTogglePanel(puObject *cb)
                                   fgGetInt("/sim/startup/ysize"));
 }
 
-void goodBye(puObject *)
-{
-    // SG_LOG( SG_INPUT, SG_ALERT,
-    //      "Program exiting normally at user request." );
-    cout << "Program exiting normally at user request." << endl;
-
-    exit(0);
-}
-
-
-void goAwayCb (puObject *me)
-{
-    FG_POP_PUI_DIALOG( dialogBox );
-}
-
-void mkDialogInit (void)
-{
-    //  printf("mkDialogInit\n");
-    int x = (fgGetInt("/sim/startup/xsize")/2 - 400/2);
-    int y = (fgGetInt("/sim/startup/ysize")/2 - 100/2);
-    dialogBox = new puDialogBox (x, y); // 150, 50
-    {
-        dialogFrame = new puFrame (0,0,400,100);
-        dialogBoxMessage  =  new puText         (10, 70);
-        dialogBoxMessage  -> setLabel           ("");
-        dialogBoxOkButton =  new puOneShot      (180, 10, 240, 50);
-        dialogBoxOkButton -> setLegend          (gui_msg_OK);
-        dialogBoxOkButton -> makeReturnDefault  (TRUE );
-        dialogBoxOkButton -> setCallback        (goAwayCb);
-    }
-    FG_FINALIZE_PUI_DIALOG( dialogBox );
-}
-
-void MayBeGoodBye(puObject *)
-{
-    ConfirmExitDialog(); 
-}
-
-void goAwayYesNoCb(puObject *me)
-{
-    FG_POP_PUI_DIALOG( YNdialogBox);
-}
-
-void ConfirmExitDialogInit(void)
-{
-    char msg[] = "Really Quit";
-    char *s;
-
-    //  printf("ConfirmExitDialogInit\n");
-    int len = 200 - puGetDefaultLabelFont().getStringWidth ( msg ) / 2;
-
-    int x = (fgGetInt("/sim/startup/xsize")/2 - 400/2);
-    int y = (fgGetInt("/sim/startup/ysize")/2 - 100/2);
-	
-    YNdialogBox = new puDialogBox (x, y); // 150, 50
-    {
-        YNdialogFrame = new puFrame (0,0,400, 100);
-        
-        YNdialogBoxMessage  =  new puText         (len, 70);
-        YNdialogBoxMessage  -> setDefaultValue    (msg);
-        YNdialogBoxMessage  -> getDefaultValue    (&s);
-        YNdialogBoxMessage  -> setLabel           (s);
-        
-        YNdialogBoxOkButton =  new puOneShot      (100, 10, 160, 50);
-        YNdialogBoxOkButton -> setLegend          (gui_msg_OK);
-        YNdialogBoxOkButton -> makeReturnDefault  (TRUE );
-        YNdialogBoxOkButton -> setCallback        (goodBye);
-        
-        YNdialogBoxNoButton =  new puOneShot      (240, 10, 300, 50);
-        YNdialogBoxNoButton -> setLegend          (gui_msg_NO);
-        YNdialogBoxNoButton -> setCallback        (goAwayYesNoCb);
-    }
-    FG_FINALIZE_PUI_DIALOG( YNdialogBox );
-}
-
-void notCb (puObject *)
-{
-    mkDialog ("This function isn't implemented yet");
-}
-
 void helpCb (puObject *)
 {
     string command;
@@ -664,17 +424,14 @@ void fgHiResDump()
 
     fclose(f);
 
-    message = "Snap shot saved to ";
+    message = "Snapshot saved to \"";
     message += filename;
+    message += "\".";
     mkDialog (message.c_str());
 
     free(tile);
     free(buffer);
 
-    //	message = "Snap shot saved to ";
-    //	message += filename;
-    //	mkDialog (message.c_str());
-
     delete [] filename;
 
     if ( show_pu_cursor ) {
@@ -707,7 +464,7 @@ GLubyte *hiResScreenCapture( int multiplier )
     globals->get_renderer()->init();
     int cur_width = fgGetInt("/sim/startup/xsize");
     int cur_height = fgGetInt("/sim/startup/ysize");
-    if (b1) delete( b1 );
+    delete( b1 );
     // New empty (mostly) bitmap
     b1 = new GlBitmap( GL_RGB, 1, 1, (unsigned char *)"123" );
     int x,y;
@@ -806,11 +563,13 @@ void fgDumpSnapShot () {
     if ( sg_glDumpWindow( filename,
 			  fgGetInt("/sim/startup/xsize"), 
 			  fgGetInt("/sim/startup/ysize")) ) {
-	message = "Snap shot saved to ";
+	message = "Snapshot saved to \"";
 	message += filename;
+	message += "\".";
     } else {
-        message = "Failed to save to ";
+        message = "Failed to save to \"";
 	message += filename;
+	message += "\".";
     }
 
     mkDialog (message.c_str());
