@@ -18,14 +18,14 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: input.cxx,v 1.55 2005/01/17 10:48:35 ehofman Exp $
+// $Id: input.cxx,v 1.70 2005/11/12 10:51:58 mfranz Exp $
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
 #ifdef HAVE_WINDOWS_H
-#  include <windows.h>                     
+#  include <windows.h>
 #endif
 
 #include <simgear/compiler.h>
@@ -50,6 +50,7 @@
 #include <Cockpit/panel_io.hxx>
 #include <GUI/gui.h>
 #include <Model/panelnode.hxx>
+#include <Scripting/NasalSys.hxx>
 
 #include <Main/globals.hxx>
 #include <Main/fg_props.hxx>
@@ -92,6 +93,11 @@ FGBinding::FGBinding (const SGPropertyNode * node)
   read(node);
 }
 
+FGBinding::~FGBinding ()
+{
+  _arg->getParent()->removeChild(_arg->getName(), _arg->getIndex(), false);
+}
+
 void
 FGBinding::read (const SGPropertyNode * node)
 {
@@ -106,9 +112,8 @@ FGBinding::read (const SGPropertyNode * node)
     return;
   }
 
-  _arg = new SGPropertyNode;
+  _arg = (SGPropertyNode *)node;
   _setting = 0;
-  copyProperties(node, _arg);  // FIXME: don't use whole node!!!
 }
 
 void
@@ -185,6 +190,12 @@ FGInput::reinit ()
     init();
 }
 
+void
+FGInput::postinit ()
+{
+  _postinit_joystick();
+}
+
 void 
 FGInput::update (double dt)
 {
@@ -232,18 +243,15 @@ FGInput::doKey (int k, int modifiers, int x, int y)
   button &b = _key_bindings[k];
 
                                 // Key pressed.
-  if (modifiers&KEYMOD_RELEASED == 0) {
+  if (!(modifiers & KEYMOD_RELEASED)) {
     SG_LOG( SG_INPUT, SG_DEBUG, "User pressed key " << k
             << " with modifiers " << modifiers );
     if (!b.last_state || b.is_repeatable) {
-      const binding_list_t &bindings =
-        _find_key_bindings(k, modifiers);
-      int max = bindings.size();
-      if (max > 0) {
-        for (int i = 0; i < max; i++)
-          bindings[i]->fire();
-        return;
-      }
+      const binding_list_t &bindings = _find_key_bindings(k, modifiers);
+
+      for (unsigned int i = 0; i < bindings.size(); i++)
+        bindings[i]->fire();
+      b.last_state = 1;
     }
   }
                                 // Key released.
@@ -251,13 +259,26 @@ FGInput::doKey (int k, int modifiers, int x, int y)
     SG_LOG(SG_INPUT, SG_DEBUG, "User released key " << k
            << " with modifiers " << modifiers);
     if (b.last_state) {
-      const binding_list_t &bindings =
-        _find_key_bindings(k, modifiers);
-      int max = bindings.size();
-      if (max > 0) {
-        for (int i = 0; i < max; i++)
-          bindings[i]->fire();
-        return;
+      const binding_list_t &bindings = _find_key_bindings(k, modifiers);
+      for (unsigned int i = 0; i < bindings.size(); i++)
+        bindings[i]->fire();
+      b.last_state = 0;
+    } else {
+      if (k >= 1 && k <= 26) {
+        if (_key_bindings[k + '@'].last_state)
+          doKey(k + '@', KEYMOD_RELEASED, x, y);
+        if (_key_bindings[k + '`'].last_state)
+          doKey(k + '`', KEYMOD_RELEASED, x, y);
+      } else if (k >= 'A' && k <= 'Z') {
+        if (_key_bindings[k - '@'].last_state)
+          doKey(k - '@', KEYMOD_RELEASED, x, y);
+        if (_key_bindings[tolower(k)].last_state)
+           doKey(tolower(k), KEYMOD_RELEASED, x, y);
+      } else if (k >= 'a' && k <= 'z') {
+        if (_key_bindings[k - '`'].last_state)
+          doKey(k - '`', KEYMOD_RELEASED, x, y);
+        if (_key_bindings[toupper(k)].last_state)
+          doKey(toupper(k), KEYMOD_RELEASED, x, y);
       }
     }
   }
@@ -370,6 +391,7 @@ void
 FGInput::_init_keyboard ()
 {
   SG_LOG(SG_INPUT, SG_DEBUG, "Initializing key bindings");
+  _module[0] = 0;
   SGPropertyNode * key_nodes = fgGetNode("/input/keyboard");
   if (key_nodes == 0) {
     SG_LOG(SG_INPUT, SG_WARN, "No key bindings (/input/keyboard)!!");
@@ -383,66 +405,129 @@ FGInput::_init_keyboard ()
 
     _key_bindings[index].bindings->clear();
     _key_bindings[index].is_repeatable = keys[i]->getBoolValue("repeatable");
+    _key_bindings[index].last_state = 0;
     _read_bindings(keys[i], _key_bindings[index].bindings, KEYMOD_NONE);
   }
 }
 
 
+void
+FGInput::_scan_joystick_dir(SGPath *path, SGPropertyNode* node, int *index)
+{
+  ulDir *dir = ulOpenDir(path->c_str());
+  if (dir) {
+    ulDirEnt* dent;
+    while ((dent = ulReadDir(dir)) != 0) {
+      if (dent->d_name[0] == '.')
+        continue;
+
+      SGPath p(path->str());
+      p.append(dent->d_name);
+      _scan_joystick_dir(&p, node, index);
+    }
+    ulCloseDir(dir);
+
+  } else if (path->extension() == "xml") {
+    SG_LOG(SG_INPUT, SG_DEBUG, "Reading joystick file " << path->str());
+    SGPropertyNode *n = node->getChild("js-named", (*index)++, true);
+    readProperties(path->str(), n);
+    n->setStringValue("source", path->c_str());
+  }
+}
+
+
 void
 FGInput::_init_joystick ()
 {
   jsInit();
                                 // TODO: zero the old bindings first.
   SG_LOG(SG_INPUT, SG_DEBUG, "Initializing joystick bindings");
-  SGPropertyNode * js_nodes = fgGetNode("/input/joysticks");
-  if (js_nodes == 0) {
-    SG_LOG(SG_INPUT, SG_WARN, "No joystick bindings (/input/joysticks)!!");
-    js_nodes = fgGetNode("/input/joysticks", true);
+  SGPropertyNode * js_nodes = fgGetNode("/input/joysticks", true);
+
+  // read all joystick xml files into /input/joysticks/js_named[1000++]
+  SGPath path(globals->get_fg_root());
+  path.append("Input/Joysticks");
+  int js_named_index = 1000;
+  _scan_joystick_dir(&path, js_nodes, &js_named_index);
+
+  // build name->node map with each <name> (reverse order)
+  map<string, SGPropertyNode_ptr> jsmap;
+  vector<SGPropertyNode_ptr> js_named = js_nodes->getChildren("js-named");
+
+  for (int k = (int)js_named.size() - 1; k >= 0; k--) {
+    SGPropertyNode *n = js_named[k];
+    vector<SGPropertyNode_ptr> names = n->getChildren("name");
+    if (names.size() && (n->getChildren("axis").size() || n->getChildren("button").size()))
+      for (unsigned int j = 0; j < names.size(); j++)
+        jsmap[names[j]->getStringValue()] = n;
   }
 
+  // set up js[] nodes
   for (int i = 0; i < MAX_JOYSTICKS; i++) {
-    SGPropertyNode_ptr js_node = js_nodes->getChild("js", i);
-    if (js_node == 0) {
-      SG_LOG(SG_INPUT, SG_DEBUG, "No bindings for joystick " << i);
-      js_node = js_nodes->getChild("js", i, true);
-    }
     jsJoystick * js = new jsJoystick(i);
     _joystick_bindings[i].js = js;
+
     if (js->notWorking()) {
       SG_LOG(SG_INPUT, SG_DEBUG, "Joystick " << i << " not found");
       continue;
-    } else {
-      bool found_js = false;
-      const char * name = js->getName();
-      SG_LOG(SG_INPUT, SG_INFO, "Looking for bindings for joystick \""
-             << name << '"');
-      vector<SGPropertyNode_ptr> nodes = js_nodes->getChildren("js-named");
-      for (unsigned int i = 0; i < nodes.size(); i++) {
-        SGPropertyNode_ptr node = nodes[i];
-        vector<SGPropertyNode_ptr> name_nodes = node->getChildren("name");
-        for (unsigned int j = 0; j < name_nodes.size(); j++) {
-            const char * js_name = name_nodes[j]->getStringValue();
-            SG_LOG(SG_INPUT, SG_INFO, "  Trying \"" << js_name << '"');
-            if (!strcmp(js_name, name)) {
-                SG_LOG(SG_INPUT, SG_INFO, "  Found bindings");
-                js_node = node;
-                found_js = true;
-                break;
-            }
-        }
-        if (found_js)
-            break;
-      }
     }
+
+    const char * name = js->getName();
+    SGPropertyNode_ptr js_node = js_nodes->getChild("js", i);
+
+    if (js_node) {
+      SG_LOG(SG_INPUT, SG_INFO, "Using existing bindings for joystick " << i);
+
+    } else {
+      SG_LOG(SG_INPUT, SG_INFO, "Looking for bindings for joystick \"" << name << '"');
+      SGPropertyNode_ptr named;
+
+      if ((named = jsmap[name])) {
+        string source = named->getStringValue("source", "user defined");
+        SG_LOG(SG_INPUT, SG_INFO, "... found joystick: " << source);
+
+      } else if ((named = jsmap["default"])) {
+        string source = named->getStringValue("source", "user defined");
+        SG_LOG(SG_INPUT, SG_INFO, "No config found for joystick \"" << name
+            << "\"\nUsing default: \"" << source << '"');
+
+      } else {
+        throw sg_throwable(string("No joystick configuration file with "
+            "<name>default</name> entry found!"));
+      }
+
+      js_node = js_nodes->getChild("js", i, true);
+      copyProperties(named, js_node);
+      js_node->setStringValue("id", name);
+    }
+  }
+
+  // get rid of unused config nodes
+  js_nodes->removeChildren("js-named", false);
+}
+
+
+void
+FGInput::_postinit_joystick()
+{
+  FGNasalSys *nasalsys = (FGNasalSys *)globals->get_subsystem("nasal");
+  SGPropertyNode *js_nodes = fgGetNode("/input/joysticks");
+
+  for (int i = 0; i < MAX_JOYSTICKS; i++) {
+    SGPropertyNode_ptr js_node = js_nodes->getChild("js", i);
+    jsJoystick *js = _joystick_bindings[i].js;
+    if (!js_node || js->notWorking())
+      continue;
+
 #ifdef WIN32
     JOYCAPS jsCaps ;
     joyGetDevCaps( i, &jsCaps, sizeof(jsCaps) );
-    int nbuttons = jsCaps.wNumButtons;
+    unsigned int nbuttons = jsCaps.wNumButtons;
     if (nbuttons > MAX_JOYSTICK_BUTTONS) nbuttons = MAX_JOYSTICK_BUTTONS;
 #else
-    int nbuttons = MAX_JOYSTICK_BUTTONS;
+    unsigned int nbuttons = MAX_JOYSTICK_BUTTONS;
 #endif
-        
+
     int naxes = js->getNumAxes();
     if (naxes > MAX_JOYSTICK_AXES) naxes = MAX_JOYSTICK_AXES;
     _joystick_bindings[i].naxes = naxes;
@@ -464,14 +549,27 @@ FGInput::_init_joystick ()
     _joystick_bindings[i].axes = new axis[naxes];
     _joystick_bindings[i].buttons = new button[nbuttons];
 
+    //
+    // Initialize nasal groups.
+    //
+    string init;
+    init = "this=\"" + string(js_node->getPath()) + "\"";
+    sprintf(_module, "__js%d", i);
+    nasalsys->createModule(_module, _module, init.c_str(), init.size());
+
+    vector<SGPropertyNode_ptr> nasal = js_node->getChildren("nasal");
+    unsigned int j;
+    for (j = 0; j < nasal.size(); j++) {
+      nasal[j]->setStringValue("module", _module);
+      nasalsys->handleCommand(nasal[j]);
+    }
 
     //
     // Initialize the axes.
     //
     vector<SGPropertyNode_ptr> axes = js_node->getChildren("axis");
     size_t nb_axes = axes.size();
-    int j;
-    for (j = 0; j < (int)nb_axes; j++) {
+    for (j = 0; j < nb_axes; j++ ) {
       const SGPropertyNode * axis_node = axes[j];
       const SGPropertyNode * num_node = axis_node->getChild("number");
       int n_axis = axis_node->getIndex();
@@ -484,7 +582,7 @@ FGInput::_init_joystick ()
              continue;
       }
 
-      if (n_axis >= (size_t)naxes) {
+      if (n_axis >= naxes) {
           SG_LOG(SG_INPUT, SG_DEBUG, "Dropping bindings for axis " << n_axis);
           continue;
       }
@@ -502,7 +600,7 @@ FGInput::_init_joystick ()
       // Initialize the virtual axis buttons.
       _init_button(axis_node->getChild("low"), a.low, "low");
       a.low_threshold = axis_node->getDoubleValue("low-threshold", -0.9);
-      
+
       _init_button(axis_node->getChild("high"), a.high, "high");
       a.high_threshold = axis_node->getDoubleValue("high-threshold", 0.9);
       a.interval_sec = axis_node->getDoubleValue("interval-sec",0.0);
@@ -514,7 +612,7 @@ FGInput::_init_joystick ()
     //
     vector<SGPropertyNode_ptr> buttons = js_node->getChildren("button");
     char buf[32];
-    for (j = 0; (j < (int)buttons.size()) && (j < nbuttons); j++) {
+    for (j = 0; j < buttons.size() && j < nbuttons; j++) {
       const SGPropertyNode * button_node = buttons[j];
       const SGPropertyNode * num_node = button_node->getChild("number");
       size_t n_but = button_node->getIndex();
@@ -522,7 +620,7 @@ FGInput::_init_joystick ()
           n_but = num_node->getIntValue(TGT_PLATFORM,n_but);
       }
 
-      if (n_but >= (size_t)nbuttons) {
+      if (n_but >= nbuttons) {
           SG_LOG(SG_INPUT, SG_DEBUG, "Dropping bindings for button " << n_but);
           continue;
       }
@@ -532,8 +630,8 @@ FGInput::_init_joystick ()
       _init_button(button_node,
                    _joystick_bindings[i].buttons[n_but],
                    buf);
-      
-      // get interval-sec property             
+
+      // get interval-sec property
       button &b = _joystick_bindings[i].buttons[n_but];
       if (button_node != 0) {
         b.interval_sec = button_node->getDoubleValue("interval-sec",0.0);
@@ -547,6 +645,7 @@ FGInput::_init_joystick ()
   }
 }
 
+
 // 
 // Map of all known cursor names
 // This used to contain all the Glut cursors, but those are
@@ -572,6 +671,7 @@ void
 FGInput::_init_mouse ()
 {
   SG_LOG(SG_INPUT, SG_DEBUG, "Initializing mouse bindings");
+  _module[0] = 0;
 
   SGPropertyNode * mouse_nodes = fgGetNode("/input/mice");
   if (mouse_nodes == 0) {
@@ -686,7 +786,6 @@ FGInput::_update_joystick (double dt)
 
     js->read(&buttons, axis_values);
 
-
                                 // Fire bindings for the axes.
     for ( j = 0; j < _joystick_bindings[i].naxes; j++) {
       axis &a = _joystick_bindings[i].axes[j];
@@ -696,7 +795,6 @@ FGInput::_update_joystick (double dt)
                                 // position fires the bindings.
       if (fabs(axis_values[j] - a.last_value) > a.tolerance) {
 //      SG_LOG(SG_INPUT, SG_DEBUG, "Axis " << j << " has moved");
-        SGPropertyNode node;
         a.last_value = axis_values[j];
 //      SG_LOG(SG_INPUT, SG_DEBUG, "There are "
 //             << a.bindings[modifiers].size() << " bindings");
@@ -804,8 +902,11 @@ FGInput::_read_bindings (const SGPropertyNode * node,
   SG_LOG(SG_INPUT, SG_DEBUG, "Reading all bindings");
   vector<SGPropertyNode_ptr> bindings = node->getChildren("binding");
   for (unsigned int i = 0; i < bindings.size(); i++) {
-    SG_LOG(SG_INPUT, SG_DEBUG, "Reading binding "
-           << bindings[i]->getStringValue("command"));
+    const char *cmd = bindings[i]->getStringValue("command");
+    SG_LOG(SG_INPUT, SG_DEBUG, "Reading binding " << cmd);
+
+    if (!strcmp(cmd, "nasal") && _module[0])
+      bindings[i]->setStringValue("module", _module);
     binding_list[modifiers].push_back(new FGBinding(bindings[i]));
   }
 
@@ -872,7 +973,7 @@ FGInput::_find_key_bindings (unsigned int k, int modifiers)
 
 FGInput::button::button ()
   : is_repeatable(false),
-    last_state(-1)
+    last_state(0)
 {
 }
 
