@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: navradio.cxx,v 1.6 2005/01/19 02:11:28 curt Exp $
+// $Id: navradio.cxx,v 1.7 2005/08/22 17:49:50 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -71,7 +71,7 @@ FGNavRadio::FGNavRadio(SGPropertyNode *node) :
     last_x(0.0),
     name("nav"),
     num(0),
-    _time_before_search_sec(0.0)
+    _time_before_search_sec(-1.0)
 {
     SGPath path( globals->get_fg_root() );
     SGPath term = path;
