@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: bootstrap.cxx,v 1.13 2005/01/09 10:27:01 ehofman Exp $
+// $Id: bootstrap.cxx,v 1.16 2005/06/12 16:01:49 mfranz Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -117,6 +117,7 @@ int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
 #if defined( sgi )
 #include <sys/fpu.h>
 #include <sys/sysmp.h>
+#include <unistd.h>
 
 /*
  *  set the special "flush zero" bit (FS, bit 24) in the Control Status
@@ -194,8 +195,10 @@ int main ( int argc, char **argv ) {
                             // We must use cerr rather than
                             // logging, since logging may be
                             // disabled.
-        cerr << "Fatal error: " << t.getFormattedMessage()
-             << "\n (received from " << t.getOrigin() << ')' << endl;
+        cerr << "Fatal error: " << t.getFormattedMessage() << endl;
+        if (!t.getOrigin().empty())
+            cerr << " (received from " << t.getOrigin() << ')' << endl;
+
     } catch (...) {
         cerr << "Unknown exception in the main loop. Aborting..." << endl;
         perror("Possible cause");
@@ -211,7 +214,6 @@ void fgExitCleanup() {
     if (_bootstrap_OSInit != 0)
         fgSetMouseCursor(MOUSE_CURSOR_POINTER);
 
-    if (globals)
-        delete globals;
+    delete globals;
 }
 
