@@ -19,7 +19,7 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 //
-// $Id: fg_init.cxx,v 1.115 2004/12/27 17:35:22 ehofman Exp $
+// $Id: fg_init.cxx,v 1.138 2005/11/11 15:08:18 mfranz Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -60,19 +60,15 @@
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/misc/interpolator.hxx>
 #include <simgear/scene/material/matlib.hxx>
-#ifdef FG_USE_CLOUDS_3D
-#  include <simgear/scene/sky/clouds3d/SkySceneLoader.hpp>
-#  include <simgear/scene/sky/clouds3d/SkyUtil.hpp>
-#  include <simgear/screen/texture.hxx>
-#endif
 #include <simgear/timing/sg_time.hxx>
 #include <simgear/timing/lowleveltime.h>
 
 #include <Aircraft/aircraft.hxx>
-#include <FDM/UIUCModel/uiuc_aircraftdir.h>
+#include <Aircraft/replay.hxx>
 #include <Airports/apt_loader.hxx>
 #include <Airports/runways.hxx>
 #include <Airports/simple.hxx>
+#include <AIModel/AIManager.hxx>
 #include <ATC/ATCdisplay.hxx>
 #include <ATC/ATCmgr.hxx>
 #include <ATC/AIMgr.hxx>
@@ -104,7 +100,6 @@
 #include <AIModel/AIManager.hxx>
 #include <Navaids/navdb.hxx>
 #include <Navaids/navlist.hxx>
-#include <Replay/replay.hxx>
 #include <Scenery/scenery.hxx>
 #include <Scenery/tilemgr.hxx>
 #include <Scripting/NasalSys.hxx>
@@ -113,15 +108,12 @@
 #include <Sound/morse.hxx>
 #include <Systems/system_mgr.hxx>
 #include <Time/light.hxx>
-#include <Time/moonpos.hxx>
-#include <Time/sunpos.hxx>
 #include <Time/sunsolver.hxx>
 #include <Time/tmp.hxx>
 #include <Traffic/TrafficMgr.hxx>
 
 #ifdef FG_MPLAYER_AS
-#include <MultiPlayer/multiplaytxmgr.hxx>
-#include <MultiPlayer/multiplayrxmgr.hxx>
+#include <MultiPlayer/multiplaymgr.hxx>
 #endif
 
 #include <Environment/environment_mgr.hxx>
@@ -147,11 +139,6 @@ extern const char *default_root;
 float init_volume;
 
 
-#ifdef FG_USE_CLOUDS_3D
-  SkySceneLoader *sgCloud3d;
-#endif
-
-
 // Scan the command line options for the specified option and return
 // the value.
 static string fgScanForOption( const string& option, int argc, char **argv ) {
@@ -340,6 +327,12 @@ bool fgInitFGAircraft ( int argc, char **argv ) {
         }
     }
 
+    if ( aircraft.empty() ) {
+        // Check for $fg_root/system.fgfsrc
+        SGPath sysconf( globals->get_fg_root() );
+        sysconf.append( "system.fgfsrc" );
+        aircraft = fgScanForOption( "--aircraft=", sysconf.str() );
+    }
     // if an aircraft was specified, set the property name
     if ( !aircraft.empty() ) {
         SG_LOG(SG_INPUT, SG_INFO, "aircraft = " << aircraft );
@@ -534,7 +527,7 @@ static string fgFindAircraftPath( const SGPath &path, const string &aircraft ) {
     ulDirEnt* dire;
     ulDir *dirp = ulOpenDir(path.str().c_str());
     if (dirp == NULL) {
-        cerr << "Unable to open aircraft directory." << endl;
+        cerr << "Unable to open aircraft directory '" << path.str() << '\'' << endl;
         exit(-1);
     }
 
@@ -624,27 +617,27 @@ bool fgInitConfig ( int argc, char **argv ) {
 
 // find basic airport location info from airport database
 bool fgFindAirportID( const string& id, FGAirport *a ) {
-    FGAirport result;
+    const FGAirport* result;
     if ( id.length() ) {
         SG_LOG( SG_GENERAL, SG_INFO, "Searching for airport code = " << id );
 
         result = globals->get_airports()->search( id );
 
-        if ( result._id.empty() ) {
+        if ( result == NULL ) {
             SG_LOG( SG_GENERAL, SG_ALERT,
-                    "Failed to find " << id << " in basic.dat.gz" );
+                    "Failed to find " << id << " in apt.dat.gz" );
             return false;
         }
     } else {
         return false;
     }
 
-    *a = result;
+    *a = *result;
 
     SG_LOG( SG_GENERAL, SG_INFO,
             "Position for " << id << " is ("
-            << a->_longitude << ", "
-            << a->_latitude << ")" );
+            << a->getLongitude() << ", "
+            << a->getLatitude() << ")" );
 
     return true;
 }
@@ -659,7 +652,7 @@ static double fgGetAirportElev( const string& id ) {
             "Finding elevation for airport: " << id );
 
     if ( fgFindAirportID( id, &a ) ) {
-        return a._elevation;
+        return a.getElevation();
     } else {
         return -9999.0;
     }
@@ -712,9 +705,9 @@ static bool fgSetTowerPosFromAirportID( const string& id, double hdg ) {
     float fudge_lat = .003f - fudge_lon;
 
     if ( fgFindAirportID( id, &a ) ) {
-        fgSetDouble("/sim/tower/longitude-deg",  a._longitude + fudge_lon);
-        fgSetDouble("/sim/tower/latitude-deg",  a._latitude + fudge_lat);
-        fgSetDouble("/sim/tower/altitude-ft", a._elevation + towerheight);
+        fgSetDouble("/sim/tower/longitude-deg",  a.getLongitude() + fudge_lon);
+        fgSetDouble("/sim/tower/latitude-deg",  a.getLatitude() + fudge_lat);
+        fgSetDouble("/sim/tower/altitude-ft", a.getElevation() + towerheight);
         return true;
     } else {
         return false;
@@ -722,6 +715,18 @@ static bool fgSetTowerPosFromAirportID( const string& id, double hdg ) {
 
 }
 
+struct FGTowerLocationListener : SGPropertyChangeListener {
+    void valueChanged(SGPropertyNode* node) {
+        const double hdg = fgGetDouble( "/orientation/heading-deg", 0);
+        const string id(node->getStringValue());
+        fgSetTowerPosFromAirportID(id, hdg);
+    }
+};
+
+static void fgInitTowerLocationListener() {
+    fgGetNode("/sim/tower/airport-id",  true)
+	->addChangeListener( new FGTowerLocationListener() );
+}
 
 // Set current_options lon/lat given an airport id and heading (degrees)
 static bool fgSetPosFromAirportIDandHdg( const string& id, double tgt_hdg ) {
@@ -958,7 +963,49 @@ static bool fgSetPosFromNAV( const string& id, const double& freq ) {
     }
 }
 
+// Set current_options lon/lat given an aircraft carrier id
+static bool fgSetPosFromCarrier( const string& carrier, const string& posid ) {
 
+    // set initial position from runway and heading
+    Point3D geodPos;
+    double heading;
+    sgdVec3 uvw;
+    if (FGAIManager::getStartPosition(carrier, posid, geodPos, heading, uvw)) {
+        double lon = geodPos.lon() * SGD_RADIANS_TO_DEGREES;
+        double lat = geodPos.lat() * SGD_RADIANS_TO_DEGREES;
+        double alt = geodPos.elev() * SG_METER_TO_FEET;
+
+        SG_LOG( SG_GENERAL, SG_INFO, "Attempting to set starting position for "
+                << carrier << " at lat = " << lat << ", lon = " << lon
+                << ", alt = " << alt << ", heading = " << heading);
+
+        fgSetDouble("/sim/presets/longitude-deg",  lon);
+        fgSetDouble("/sim/presets/latitude-deg",  lat);
+        fgSetDouble("/sim/presets/altitude-ft", alt);
+        fgSetDouble("/sim/presets/heading-deg", heading);
+        fgSetDouble("/position/longitude-deg",  lon);
+        fgSetDouble("/position/latitude-deg",  lat);
+        fgSetDouble("/position/altitude-ft", alt);
+        fgSetDouble("/orientation/heading-deg", heading);
+
+        fgSetString("/sim/presets/speed-set", "UVW");
+        fgSetDouble("/velocities/uBody-fps", uvw[0]);
+        fgSetDouble("/velocities/vBody-fps", uvw[1]);
+        fgSetDouble("/velocities/wBody-fps", uvw[2]);
+        fgSetDouble("/sim/presets/uBody-fps", uvw[0]);
+        fgSetDouble("/sim/presets/vBody-fps", uvw[1]);
+        fgSetDouble("/sim/presets/wBody-fps", uvw[2]);
+
+        fgSetBool("/sim/presets/onground", true);
+
+        return true;
+    } else {
+        SG_LOG( SG_GENERAL, SG_ALERT, "Failed to locate aircraft carrier = "
+                << carrier );
+        return false;
+    }
+}
+ 
 // Set current_options lon/lat given an airport id and heading (degrees)
 static bool fgSetPosFromFix( const string& id ) {
     FGFix fix;
@@ -1058,14 +1105,20 @@ fgInitNav ()
     FGNavList *gslist = new FGNavList;
     FGNavList *dmelist = new FGNavList;
     FGNavList *mkrlist = new FGNavList;
+    FGNavList *tacanlist = new FGNavList;
+    FGNavList *carrierlist = new FGNavList;
+    FGTACANList *channellist = new FGTACANList;
 
     globals->set_navlist( navlist );
     globals->set_loclist( loclist );
     globals->set_gslist( gslist );
     globals->set_dmelist( dmelist );
     globals->set_mkrlist( mkrlist );
+    globals->set_tacanlist( tacanlist );
+    globals->set_carrierlist( carrierlist );
+    globals->set_channellist( channellist );
 
-    if ( !fgNavDBInit(airports, navlist, loclist, gslist, dmelist, mkrlist) ) {
+    if ( !fgNavDBInit(airports, navlist, loclist, gslist, dmelist, mkrlist, tacanlist, carrierlist, channellist) ) {
         SG_LOG( SG_GENERAL, SG_ALERT,
                 "Problems loading one or more navigational database" );
     }
@@ -1131,14 +1184,19 @@ bool fgInitPosition() {
     double vor_freq = fgGetDouble("/sim/presets/vor-freq");
     string ndb = fgGetString("/sim/presets/ndb-id");
     double ndb_freq = fgGetDouble("/sim/presets/ndb-freq");
+    string carrier = fgGetString("/sim/presets/carrier");
+    string parkpos = fgGetString("/sim/presets/parkpos");
     string fix = fgGetString("/sim/presets/fix");
 
+    fgSetDouble( "/orientation/heading-deg", hdg );
+    fgInitTowerLocationListener();
+
     if ( !set_pos && !apt.empty() && !rwy_no.empty() ) {
         // An airport + runway is requested
         if ( fgSetPosFromAirportIDandRwy( apt, rwy_no ) ) {
             // set tower position (a little off the heading for single
             // runway airports)
-            fgSetTowerPosFromAirportID( apt, hdg );
+	    fgSetString("/sim/tower/airport-id",  apt.c_str());
             set_pos = true;
         }
     }
@@ -1148,7 +1206,7 @@ bool fgInitPosition() {
         if ( fgSetPosFromAirportIDandHdg( apt, hdg ) ) {
             // set tower position (a little off the heading for single
             // runway airports)
-            fgSetTowerPosFromAirportID( apt, hdg );
+	    fgSetString("/sim/tower/airport-id",  apt.c_str());
             set_pos = true;
         }
     }
@@ -1167,6 +1225,13 @@ bool fgInitPosition() {
         }
     }
 
+    if ( !set_pos && !carrier.empty() ) {
+        // an aircraft carrier is requested
+        if ( fgSetPosFromCarrier( carrier, parkpos ) ) {
+            set_pos = true;
+        }
+    }
+
     if ( !set_pos && !fix.empty() ) {
         // a Fix is requested
         if ( fgSetPosFromFix( fix ) ) {
@@ -1185,11 +1250,9 @@ bool fgInitPosition() {
                  fgGetDouble("/sim/presets/longitude-deg") );
     fgSetDouble( "/position/latitude-deg",
                  fgGetDouble("/sim/presets/latitude-deg") );
-    fgSetDouble( "/orientation/heading-deg",
-                 fgGetDouble("/sim/presets/heading-deg") );
 
     // determine if this should be an on-ground or in-air start
-    if ( fabs(gs) > 0.01 || fabs(od) > 0.1 || alt > 0.1 ) {
+    if ((fabs(gs) > 0.01 || fabs(od) > 0.1 || alt > 0.1) && carrier.empty()) {
         fgSetBool("/sim/presets/onground", false);
     } else {
         fgSetBool("/sim/presets/onground", true);
@@ -1251,8 +1314,7 @@ void fgInitFDM() {
     }
 
     double dt = 1.0 / fgGetInt("/sim/model-hz");
-    aircraft_dir = fgGetString("/sim/aircraft-dir");
-    const string &model = fgGetString("/sim/flight-model");
+    string model = fgGetString("/sim/flight-model");
 
     try {
         if ( model == "larcsim" ) {
@@ -1309,8 +1371,22 @@ void fgInitFDM() {
             }
             cur_fdm_state = new FGExternalNet( dt, host, port1, port2, port3 );
         } else if ( model.find("pipe") == 0 ) {
-            string pipe_path = model.substr(5);
-            cur_fdm_state = new FGExternalPipe( dt, pipe_path );
+            // /* old */ string pipe_path = model.substr(5);
+            // /* old */ cur_fdm_state = new FGExternalPipe( dt, pipe_path );
+            string pipe_path = "";
+            string pipe_protocol = "";
+            string pipe_options = model.substr(5);
+            string::size_type begin, end;
+            begin = 0;
+            // pipe file path
+            end = pipe_options.find( ",", begin );
+            if ( end != string::npos ) {
+                pipe_path = pipe_options.substr(begin, end - begin);
+                begin = end + 1;
+            }
+            // protocol (last option)
+            pipe_protocol = pipe_options.substr(begin);
+            cur_fdm_state = new FGExternalPipe( dt, pipe_path, pipe_protocol );
         } else if ( model == "null" ) {
             cur_fdm_state = new FGNullFDM( dt );
         } else if ( model == "yasim" ) {
@@ -1399,7 +1475,7 @@ void fgInitTimeOffset() {
 
     // Okay, we now have several possible scenarios
     int offset = fgGetInt("/sim/startup/time-offset");
-    const string &offset_type = fgGetString("/sim/startup/time-offset-type");
+    string offset_type = fgGetString("/sim/startup/time-offset-type");
 
     int warp = 0;
     if ( offset_type == "real" ) {
@@ -1501,7 +1577,7 @@ bool fgInitSubsystems() {
     ////////////////////////////////////////////////////////////////////
 
     globals->get_event_mgr()->init();
-    globals->get_event_mgr()->setFreezeProperty(fgGetNode("/sim/freeze/clock"));
+    globals->get_event_mgr()->setRealtimeProperty(fgGetNode("/sim/time/delta-realtime-sec", true));
 
     ////////////////////////////////////////////////////////////////////
     // Initialize the property interpolator subsystem
@@ -1520,7 +1596,8 @@ bool fgInitSubsystems() {
 
     SGPath mpath( globals->get_fg_root() );
     mpath.append( "materials.xml" );
-    if ( ! globals->get_matlib()->load(globals->get_fg_root(), mpath.str()) ) {
+    string season = fgGetString("/sim/startup/season", "summer");
+    if ( ! globals->get_matlib()->load(globals->get_fg_root(), mpath.str(), season.c_str()) ) {
         SG_LOG( SG_GENERAL, SG_ALERT, "Error loading material lib!" );
         exit(-1);
     }
@@ -1546,10 +1623,6 @@ bool fgInitSubsystems() {
                                        &FGTileMgr::refresh_view_timestamps,
                                        15 );
 
-    SG_LOG( SG_GENERAL, SG_DEBUG,
-            "Current terrain elevation after tile mgr init " <<
-            globals->get_scenery()->get_cur_elev() );
-
 
     ////////////////////////////////////////////////////////////////////
     // Initialize the flight model subsystem.
@@ -1596,6 +1669,7 @@ bool fgInitSubsystems() {
     // update the current timezone each 30 minutes
     globals->get_event_mgr()->addTask( "fgUpdateLocalTime()",
                                        &fgUpdateLocalTime, 30*60 );
+    fgInitTimeOffset();		// the environment subsystem needs this
 
 
     ////////////////////////////////////////////////////////////////////
@@ -1617,40 +1691,6 @@ bool fgInitSubsystems() {
     ////////////////////////////////////////////////////////////////////
     fgGetBool("/sim/rendering/bump-mapping", false);
 
-#ifdef FG_USE_CLOUDS_3D
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the 3D cloud subsystem.
-    ////////////////////////////////////////////////////////////////////
-    if ( fgGetBool("/sim/rendering/clouds3d") ) {
-        static const SGPropertyNode *longitude
-           = fgGetNode("/sim/presets/longitude-deg");
-        static const SGPropertyNode *latitude
-           = fgGetNode("/sim/presets/latitude-deg");
-        // static const SGPropertyNode *altitude
-        //    = fgGetNode("/sim/presets/altitude-ft");
-
-        SGPath cloud_path(globals->get_fg_root());
-#if 0
-        cloud_path.append("Textures/Sky/scattered.rgba");
-        SG_LOG(SG_GENERAL, SG_INFO, "Loading CLOUDS3d from: " << cloud_path.c_str());
-
-        SGTexture tx;
-        tx.read_rgba_texture(cloud_path.c_str());
-        if ( !sgCloud3d->Load( tx.texture(), tx.width(),
-#else
-        cloud_path.append("large.sky");
-        if ( !sgCloud3d->Load( cloud_path.str(),
-#endif
-                               latitude->getDoubleValue(),
-                               longitude->getDoubleValue()) )
-        {
-            fgSetBool("/sim/rendering/clouds3d", false);
-            SG_LOG(SG_GENERAL, SG_INFO, "CLOUDS3d FAILED: ");
-        }
-        SG_LOG(SG_GENERAL, SG_INFO, "CLOUDS3d Loaded: ");
-    }
-#endif
-
 #ifdef ENABLE_AUDIO_SUPPORT
     ////////////////////////////////////////////////////////////////////
     // Initialize the sound subsystem.
@@ -1709,11 +1749,11 @@ bool fgInitSubsystems() {
      globals->add_subsystem("Traffic Manager", new FGTrafficManager);
 	     FGTrafficManager *dispatcher = 
 	     (FGTrafficManager*) globals->get_subsystem("Traffic Manager");
-	     SGPath path =globals->get_fg_root();
-	     path.append("Traffic/fgtraffic.xml");
+	     SGPath path = globals->get_fg_root();
+	     path.append("/Traffic/fgtraffic.xml");
      readXML(path.str(),
-	     *dispatcher);
-     globals->get_subsystem("Traffic Manager")->init();
+	*dispatcher);
+	     //globals->get_subsystem("Traffic Manager")->init();
 
     globals->add_subsystem("instrumentation", new FGInstrumentMgr);
     globals->add_subsystem("systems", new FGSystemMgr);
@@ -1800,11 +1840,8 @@ bool fgInitSubsystems() {
     // Initialize multiplayer subsystem
     ////////////////////////////////////////////////////////////////////
 
-    globals->set_multiplayer_tx_mgr(new FGMultiplayTxMgr);
-    globals->get_multiplayer_tx_mgr()->init();
-
-    globals->set_multiplayer_rx_mgr(new FGMultiplayRxMgr);
-    globals->get_multiplayer_rx_mgr()->init();
+    globals->set_multiplayer_mgr(new FGMultiplayMgr);
+    globals->get_multiplayer_mgr()->init();
 #endif
 
     ////////////////////////////////////////////////////////////////////////
@@ -1820,6 +1857,8 @@ bool fgInitSubsystems() {
     ///////////////////////////////////////////////////////////////////
     parseWaypoints();
 
+    // initialize methods that depend on other subsystems.
+    globals->get_subsystem_mgr()->postinit();
 
     ////////////////////////////////////////////////////////////////////////
     // End of subsystem initialization.
@@ -1856,6 +1895,10 @@ void fgReInitSubsystems()
     }
     fgSetBool("/sim/crashed", false);
 
+    // Force reupdating the positions of the ai 3d models. They are used for
+    // initializing ground level for the FDM.
+    globals->get_subsystem("ai_model")->reinit();
+
     // Initialize the FDM
     fgInitFDM();
     
