@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: fg_props.cxx,v 1.20 2004/10/24 11:05:14 ehofman Exp $
+// $Id: fg_props.cxx,v 1.22 2005/11/17 15:47:01 curt Exp $
 
 #ifdef HAVE_CONFIG_H
 #  include <simgear/compiler.h>
@@ -36,7 +36,6 @@
 #include <ATC/ATCdisplay.hxx>
 #include <Aircraft/aircraft.hxx>
 #include <Time/tmp.hxx>
-#include <FDM/UIUCModel/uiuc_aircraftdir.h>
 #include <Environment/environment.hxx>
 
 #include <GUI/gui.h>
@@ -238,26 +237,6 @@ setFreeze (bool f)
 }
 
 
-/**
- * Return the current aircraft directory (UIUC) as a string.
- */
-static const char *
-getAircraftDir ()
-{
-  return aircraft_dir.c_str();
-}
-
-
-/**
- * Set the current aircraft directory (UIUC).
- */
-static void
-setAircraftDir (const char * dir)
-{
-  aircraft_dir = dir;
-}
-
-
 /**
  * Return the number of milliseconds elapsed since simulation started.
  */
@@ -477,7 +456,6 @@ FGProperties::bind ()
   fgTie("/sim/logging/priority", getLoggingPriority, setLoggingPriority);
   fgTie("/sim/logging/classes", getLoggingClasses, setLoggingClasses);
   fgTie("/sim/freeze/master", getFreeze, setFreeze);
-  fgTie("/sim/aircraft-dir", getAircraftDir, setAircraftDir);
 
   fgTie("/sim/time/elapsed-sec", getElapsedTime_sec);
   fgTie("/sim/time/gmt", getDateString, setDateString);
@@ -506,7 +484,6 @@ FGProperties::unbind ()
   fgUntie("/sim/logging/priority");
   fgUntie("/sim/logging/classes");
   fgUntie("/sim/freeze/master");
-  fgUntie("/sim/aircraft-dir");
 
   fgUntie("/sim/time/elapsed-sec");
   fgUntie("/sim/time/gmt");
@@ -532,7 +509,7 @@ void
 FGProperties::update (double dt)
 {
                                 // Date and time
-    struct tm * t = globals->get_time_params()->getGmt();
+    struct tm *t = globals->get_time_params()->getGmt();
 
     fgSetInt("/sim/time/utc/year", t->tm_year + 1900);
     fgSetInt("/sim/time/utc/month", t->tm_mon + 1);
@@ -545,6 +522,9 @@ FGProperties::update (double dt)
                 t->tm_hour * 3600 +
                 t->tm_min * 60 +
                 t->tm_sec);
+
+    fgSetInt("/sim/time/local-offset",
+             globals->get_time_params()->get_local_offset());
 }
 
 
