@@ -18,14 +18,18 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: globals.cxx,v 1.34 2004/11/19 22:10:43 curt Exp $
+// $Id: globals.cxx,v 1.38 2005/10/22 11:22:06 ehofman Exp $
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 
 #include <simgear/sound/soundmgr_openal.hxx>
 #include <simgear/structure/commands.hxx>
 #include <simgear/misc/sg_path.hxx>
 
 #include "globals.hxx"
+#include "renderer.hxx"
 #include "viewmgr.hxx"
 
 #include "fg_props.hxx"
@@ -81,6 +85,8 @@ FGGlobals::FGGlobals() :
     gslist( NULL ),
     dmelist( NULL ),
     mkrlist( NULL ),
+    tacanlist( NULL ),
+    carrierlist( NULL ), 
     fixlist( NULL )
 {
 }
@@ -97,11 +103,7 @@ FGGlobals::~FGGlobals()
     delete commands;
     delete io;
     delete renderer;
-  
-    // make sure only to delete the initial waypoints list if it acually
-    // still exists. 
-    if (initial_waypoints)
-        delete initial_waypoints;
+    delete initial_waypoints;
 }
 
 
