@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: main.cxx,v 1.193 2005/01/05 05:45:38 curt Exp $
+// $Id: main.cxx,v 1.213 2005/11/17 22:54:46 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -47,17 +47,15 @@
 #include <simgear/timing/sg_time.hxx>
 #include <simgear/math/sg_random.h>
 
-// Class refferences
+// Class references
 #include <simgear/ephemeris/ephemeris.hxx>
 #include <simgear/scene/model/modellib.hxx>
 #include <simgear/scene/material/matlib.hxx>
 #include <simgear/scene/model/animation.hxx>
 #include <simgear/scene/sky/sky.hxx>
 #include <Time/light.hxx>
-
-
-
 #include <Include/general.hxx>
+#include <Aircraft/replay.hxx>
 #include <Cockpit/cockpit.hxx>
 #include <Cockpit/hud.hxx>
 #include <Model/panelnode.hxx>
@@ -68,20 +66,17 @@
 #include <Sound/beacon.hxx>
 #include <Sound/morse.hxx>
 #include <FDM/flight.hxx>
-#include <FDM/UIUCModel/uiuc_aircraftdir.h>
 // #include <FDM/ADA.hxx>
 #include <ATC/ATCdisplay.hxx>
 #include <ATC/ATCmgr.hxx>
 #include <ATC/AIMgr.hxx>
-#include <Replay/replay.hxx>
 #include <Time/tmp.hxx>
 #include <Time/fg_timer.hxx>
 #include <Environment/environment_mgr.hxx>
 #include <GUI/new_gui.hxx>
 
 #ifdef FG_MPLAYER_AS
-#include <MultiPlayer/multiplaytxmgr.hxx>
-#include <MultiPlayer/multiplayrxmgr.hxx>
+#include <MultiPlayer/multiplaymgr.hxx>
 #endif
 
 
@@ -142,15 +137,21 @@ void fgUpdateTimeDepCalcs() {
     // cout << "cur_fdm_state->get_inited() = " << cur_fdm_state->get_inited() 
     //      << " cur_elev = " << scenery.get_cur_elev() << endl;
 
-    if ( !cur_fdm_state->get_inited() &&
-         globals->get_scenery()->get_cur_elev() > -9990 )
-    {
-        SG_LOG(SG_FLIGHT,SG_INFO, "Finally initializing fdm");  
+    if (!cur_fdm_state->get_inited()) {
+      // Check for scenery around the aircraft.
+      double lon = fgGetDouble("/sim/presets/longitude-deg");
+      double lat = fgGetDouble("/sim/presets/latitude-deg");
+      // We require just to have 50 meter scenery availabe around
+      // the aircraft.
+      double range = 50.0;
+      if (globals->get_tile_mgr()->scenery_available(lat, lon, range)) {
+        SG_LOG(SG_FLIGHT,SG_INFO, "Finally initializing fdm");
         cur_fdm_state->init();
         if ( cur_fdm_state->get_bound() ) {
             cur_fdm_state->unbind();
         }
         cur_fdm_state->bind();
+      }
     }
 
     // conceptually, the following block could be done for each fdm
@@ -222,6 +223,8 @@ static void fgMainLoop( void ) {
 
     SGCloudLayer::enable_bump_mapping = fgGetBool("/sim/rendering/bump-mapping");
 
+    bool scenery_loaded = fgGetBool("sim/sceneryloaded") || fgGetBool("sim/sceneryloaded-override");
+
     // Update the elapsed time.
     static bool first_time = true;
     if ( first_time ) {
@@ -230,11 +233,56 @@ static void fgMainLoop( void ) {
     }
 
     double throttle_hz = fgGetDouble("/sim/frame-rate-throttle-hz", 0.0);
-    if ( throttle_hz > 0.0 ) {
-        // simple frame rate throttle
-        double dt = 1000000.0 / throttle_hz;
+    if ( throttle_hz > 0.0 && scenery_loaded ) {
+        // optionally throttle the frame rate (to get consistant frame
+        // rates or reduce cpu usage.
+
+        double frame_us = 1000000.0 / throttle_hz;
+
+#define FG_SLEEP_BASED_TIMING 1
+#if defined(FG_SLEEP_BASED_TIMING)
+        // sleep based timing loop.
+        //
+        // Calling sleep, even usleep() on linux is less accurate than
+        // we like, but it does free up the cpu for other tasks during
+        // the sleep so it is desireable.  Because of the way sleep()
+        // is implimented in consumer operating systems like windows
+        // and linux, you almost always sleep a little longer than the
+        // requested amount.
+        // 
+        // To combat the problem of sleeping to long, we calculate the
+        // desired wait time and shorten it by 2000us (2ms) to avoid
+        // [hopefully] over-sleep'ing.  The 2ms value was arrived at
+        // via experimentation.  We follow this up at the end with a
+        // simple busy-wait loop to get the final pause timing exactly
+        // right.
+        // 
+        // Assuming we don't oversleep by more than 2000us, this
+        // should be a reasonable compromise between sleep based
+        // waiting, and busy waiting.
+
+        // sleep() will always overshoot by a bit so undersleep by
+        // 2000us in the hopes of never oversleeping.
+        frame_us -= 2000.0;
+        if ( frame_us < 0.0 ) {
+            frame_us = 0.0;
+        }
         current_time_stamp.stamp();
-        while ( current_time_stamp - last_time_stamp < dt ) {
+        /* Convert to ms */
+        double elapsed_us = current_time_stamp - last_time_stamp;
+        if ( elapsed_us < frame_us ) {
+            double requested_us = frame_us - elapsed_us;
+            ulMilliSecondSleep ( (int)(requested_us / 1000.0) ) ;
+        }
+#endif
+
+        // busy wait timing loop.
+        // 
+        // This yields the most accurate timing.  If the previous
+        // ulMilliSecondSleep() call is ommitted this will peg the cpu
+        // (which is just fine if FG is the only app you care about.)
+        current_time_stamp.stamp();
+        while ( current_time_stamp - last_time_stamp < frame_us ) {
             current_time_stamp.stamp();
         }
     } else {
@@ -256,7 +304,7 @@ static void fgMainLoop( void ) {
     }
 
 
-    if ( clock_freeze->getBoolValue() ) {
+    if (clock_freeze->getBoolValue() || !scenery_loaded) {
         delta_time_sec = 0;
     } else {
         delta_time_sec = real_delta_time_sec;
@@ -391,7 +439,7 @@ static void fgMainLoop( void ) {
 #endif
 
     // Run ATC subsystem
-    if (fgGetBool("/sim/ATC/enabled"))
+    if (fgGetBool("/sim/atc/enabled"))
         globals->get_ATC_mgr()->update(delta_time_sec);
 
     // Run the AI subsystem
@@ -400,7 +448,7 @@ static void fgMainLoop( void ) {
 
 #ifdef FG_MPLAYER_AS
     // Update any multiplayer models
-    globals->get_multiplayer_rx_mgr()->Update();
+    globals->get_multiplayer_mgr()->Update();
 #endif
 
     // Run flight model
@@ -421,15 +469,11 @@ static void fgMainLoop( void ) {
         remainder = 0;
     }
 
-    bool scenery_loaded = fgGetBool("sim/sceneryloaded") || fgGetBool("sim/sceneryloaded-override");
-
     // flight model
     if ( global_multi_loop > 0) {
         // first run the flight model each frame until it is intialized
         // then continue running each frame only after initial scenery load is complete.
-        if (!cur_fdm_state->get_inited() || scenery_loaded) {
-            fgUpdateTimeDepCalcs();
-        }
+        fgUpdateTimeDepCalcs();
     } else {
         SG_LOG( SG_ALL, SG_DEBUG, 
             "Elapsed time is zero ... we're zinging" );
@@ -458,52 +502,59 @@ static void fgMainLoop( void ) {
     double visibility_meters = fgGetDouble("/environment/visibility-m");
     FGViewer *current_view = globals->get_current_view();
 
-    // get the location data for the primary FDM (now hardcoded to ac model)...
-    SGLocation *acmodel_loc = NULL;
-    acmodel_loc = (SGLocation *)globals->
-        get_aircraft_model()->get3DModel()->getSGLocation();
-
-    // update tile manager for FDM...
-    // ...only if location is different than the current-view location
-    // (to avoid duplicating effort)
-    if( !fgGetBool("/sim/current-view/config/from-model") ) {
-        if( acmodel_loc != NULL ) {
-            globals->get_tile_mgr()->prep_ssg_nodes( acmodel_loc,
-                                                     visibility_meters );
-            globals->get_tile_mgr()->
-                update( acmodel_loc, visibility_meters,
-                        acmodel_loc->
-                        get_absolute_view_pos(globals->
-                                              get_scenery()->get_center()) );
-            // save results of update in SGLocation for fdm...
-            if ( globals->get_scenery()->get_cur_elev() > -9990 ) {
-                acmodel_loc->
-                    set_cur_elev_m( globals->get_scenery()->get_cur_elev() );
-                fgSetDouble("/position/ground-elev-m",
-                            globals->get_scenery()->get_cur_elev());
-            }
-            acmodel_loc->
-                set_tile_center( globals->get_scenery()->get_next_center() );
-        }
+    // Let the scenery center follow the current view position with
+    // 30m increments.
+    //
+    // Having the scenery center near the view position will eliminate
+    // jitter of objects which are placed very near the view position
+    // and haveing it's center near that view position.
+    // So the 3d insruments of the aircraft will not jitter with this.
+    // 
+    // Following the view position exactly would introduce jitter of
+    // the scenery tiles (they would be from their center up to 10000m
+    // to the view and this will introduce roundoff too). By stepping
+    // at 30m incements the roundoff error of the scenery tiles is
+    // still present, but we will make exactly the same roundoff error
+    // at each frame until the center is switched to a new
+    // position. This roundoff is still visible but you will most
+    // propably not notice.
+    double *vp = globals->get_current_view()->get_absolute_view_pos();
+    Point3D cntr(vp[0], vp[1], vp[2]);
+    if (30.0*30.0 < cntr.distance3Dsquared(globals->get_scenery()->get_center())) {
+      globals->get_scenery()->set_next_center( cntr );
     }
 
     globals->get_tile_mgr()->prep_ssg_nodes( current_view->getSGLocation(),
                                              visibility_meters );
     // update tile manager for view...
-    // IMPORTANT!!! the tilemgr update for view location _must_ be
-    // done last after the FDM's until all of Flight Gear code
-    // references the viewer's location for elevation instead of the
-    // "scenery's" current elevation.
     SGLocation *view_location = globals->get_current_view()->getSGLocation();
-    globals->get_tile_mgr()->update( view_location, visibility_meters,
-                                     current_view->get_absolute_view_pos() );
-    // save results of update in SGLocation for fdm...
-    if ( globals->get_scenery()->get_cur_elev() > -9990 ) {
-        current_view->getSGLocation()->
-            set_cur_elev_m( globals->get_scenery()->get_cur_elev() );
+    globals->get_tile_mgr()->update( view_location, visibility_meters );
+    globals->get_scenery()->set_center( cntr );
+    {
+      double lon = view_location->getLongitude_deg();
+      double lat = view_location->getLatitude_deg();
+      double alt = view_location->getAltitudeASL_ft() * SG_FEET_TO_METER;
+
+      // check if we can reuse the groundcache for that purpose.
+      double ref_time, pt[3], r;
+      bool valid = cur_fdm_state->is_valid_m(&ref_time, pt, &r);
+      if (valid &&
+          cntr.distance3Dsquared(Point3D(pt[0], pt[1], pt[2])) < r*r) {
+        // Reuse the cache ...
+        double lev
+          = cur_fdm_state->get_groundlevel_m(lat*SGD_DEGREES_TO_RADIANS,
+                                             lon*SGD_DEGREES_TO_RADIANS,
+                                             alt + 2.0);
+        view_location->set_cur_elev_m( lev );
+      } else {
+        // Do full intersection test.
+        double lev;
+        if (globals->get_scenery()->get_elevation_m(lat, lon, alt+2, lev))
+          view_location->set_cur_elev_m( lev );
+        else
+          view_location->set_cur_elev_m( -9999.0 );
+      }
     }
-    current_view->getSGLocation()->
-        set_tile_center( globals->get_scenery()->get_next_center() );
 
 #ifdef ENABLE_AUDIO_SUPPORT
     // Right now we make a simplifying assumption that the primary
@@ -512,11 +563,19 @@ static void fgMainLoop( void ) {
 
     static sgVec3 last_pos_offset;
 
+    // get the location data for the primary FDM (now hardcoded to ac model)...
+    SGLocation *acmodel_loc = NULL;
+    acmodel_loc = (SGLocation *)globals->
+        get_aircraft_model()->get3DModel()->getSGLocation();
+
     // set positional offset for sources
-    sgVec3 source_pos_offset;
-    sgSubVec3( source_pos_offset,
-               view_location->get_view_pos(), acmodel_loc->get_view_pos() );
+    sgdVec3 dsource_pos_offset;
+    sgdSubVec3( dsource_pos_offset,
+                view_location->get_absolute_view_pos(),
+                acmodel_loc->get_absolute_view_pos() );
     // cout << "pos all = " << source_pos_offset[0] << " " << source_pos_offset[1] << " " << source_pos_offset[2] << endl;
+    sgVec3 source_pos_offset;
+    sgSetVec3(source_pos_offset, dsource_pos_offset);
     globals->get_soundmgr()->set_source_pos_all( source_pos_offset );
 
     // set the velocity
@@ -535,22 +594,6 @@ static void fgMainLoop( void ) {
     globals->get_soundmgr()->set_listener_pos( listener_pos );
 #endif
 
-    // If fdm location is same as viewer's then we didn't do the
-    // update for fdm location above so we need to save the viewer
-    // results in the fdm SGLocation as well...
-    if( fgGetBool("/sim/current-view/config/from-model") ) {
-        if( acmodel_loc != 0 ) {
-            if ( globals->get_scenery()->get_cur_elev() > -9990 ) {
-                acmodel_loc->set_cur_elev_m( globals->get_scenery()->
-                                             get_cur_elev() );
-                fgSetDouble("/position/ground-elev-m",
-                            globals->get_scenery()->get_cur_elev());
-            }
-            acmodel_loc->set_tile_center( globals->get_scenery()->
-                                          get_next_center() );
-        }
-    }
-
     // END Tile Manager udpates
 
     if (!scenery_loaded && globals->get_tile_mgr()->all_queues_empty() && cur_fdm_state->get_inited()) {
@@ -581,16 +624,212 @@ static void fgMainLoop( void ) {
 // then on.
 
 static void fgIdleFunction ( void ) {
-    // printf("idle state == %d\n", idle_state);
-
     if ( idle_state == 0 ) {
-        // Initialize the splash screen right away
-        if ( fgGetBool("/sim/startup/splash-screen") ) {
-            fgSplashInit(fgGetString("/sim/startup/splash-texture"));
-        }
-        
         idle_state++;
+        fgSplashProgress("setting up scenegraph & user interface");
+
+
     } else if ( idle_state == 1 ) {
+        idle_state++;
+        // This seems to be the absolute earliest in the init sequence
+        // that these calls will return valid info.  Too bad it's after
+        // we've already created and sized out window. :-(
+        general.set_glVendor( (char *)glGetString ( GL_VENDOR ) );
+        general.set_glRenderer( (char *)glGetString ( GL_RENDERER ) );
+        general.set_glVersion( (char *)glGetString ( GL_VERSION ) );
+        SG_LOG( SG_GENERAL, SG_INFO, general.get_glRenderer() );
+
+        GLint tmp;
+        glGetIntegerv( GL_MAX_TEXTURE_SIZE, &tmp );
+        general.set_glMaxTexSize( tmp );
+        SG_LOG ( SG_GENERAL, SG_INFO, "Max texture size = " << tmp );
+
+        glGetIntegerv( GL_DEPTH_BITS, &tmp );
+        general.set_glDepthBits( tmp );
+        SG_LOG ( SG_GENERAL, SG_INFO, "Depth buffer bits = " << tmp );
+
+        // Initialize ssg (from plib).  Needs to come before we do any
+        // other ssg stuff, but after opengl has been initialized.
+        ssgInit();
+
+        // Initialize the user interface (we need to do this before
+        // passing off control to the OS main loop and before
+         // fgInitGeneral to get our fonts !!!
+        guiInit();
+        fgSplashProgress("reading aircraft list");
+
+
+    } else if ( idle_state == 2 ) {
+        idle_state++;
+        // Read the list of available aircrafts
+        fgReadAircraft();
+
+#ifdef GL_EXT_texture_lod_bias
+        glTexEnvf( GL_TEXTURE_FILTER_CONTROL_EXT, GL_TEXTURE_LOD_BIAS_EXT, -0.5 ) ;
+#endif
+
+        // get the address of our OpenGL extensions
+        if ( fgGetBool("/sim/rendering/distance-attenuation") ) {
+            if (SGIsOpenGLExtensionSupported("GL_EXT_point_parameters") ) {
+                glPointParameterIsSupported = true;
+                glPointParameterfPtr = (glPointParameterfProc)
+                                       SGLookupFunction("glPointParameterfEXT");
+                glPointParameterfvPtr = (glPointParameterfvProc)
+                                        SGLookupFunction("glPointParameterfvEXT");
+
+            } else if ( SGIsOpenGLExtensionSupported("GL_ARB_point_parameters") ) {
+                glPointParameterIsSupported = true;
+                glPointParameterfPtr = (glPointParameterfProc)
+                                       SGLookupFunction("glPointParameterfARB");
+                glPointParameterfvPtr = (glPointParameterfvProc)
+                                        SGLookupFunction("glPointParameterfvARB");
+            } else
+                glPointParameterIsSupported = false;
+        }
+        fgSplashProgress("reading airport & navigation data");
+
+
+    } else if ( idle_state == 3 ) {
+        idle_state++;
+        fgInitNav();
+        fgSplashProgress("setting up scenery");
+
+
+    } else if ( idle_state == 4 ) {
+        idle_state++;
+        // based on the requested presets, calculate the true starting
+        // lon, lat
+        fgInitPosition();
+
+        SGTime *t = fgInitTime();
+        globals->set_time_params( t );
+
+        // Do some quick general initializations
+        if( !fgInitGeneral()) {
+            SG_LOG( SG_GENERAL, SG_ALERT, 
+                "General initializations failed ..." );
+            exit(-1);
+        }
+
+        ////////////////////////////////////////////////////////////////////
+        // Initialize the property-based built-in commands
+        ////////////////////////////////////////////////////////////////////
+        fgInitCommands();
+
+
+        ////////////////////////////////////////////////////////////////////
+        // Initialize the material manager
+        ////////////////////////////////////////////////////////////////////
+        globals->set_matlib( new SGMaterialLib );
+        globals->set_model_lib(new SGModelLib);
+
+
+        ////////////////////////////////////////////////////////////////////
+        // Initialize the TG scenery subsystem.
+        ////////////////////////////////////////////////////////////////////
+        globals->set_scenery( new FGScenery );
+        globals->get_scenery()->init();
+        globals->get_scenery()->bind();
+        globals->set_tile_mgr( new FGTileMgr );
+
+
+        ////////////////////////////////////////////////////////////////////
+        // Initialize the general model subsystem.
+        ////////////////////////////////////////////////////////////////////
+        globals->set_model_mgr(new FGModelMgr);
+        globals->get_model_mgr()->init();
+        globals->get_model_mgr()->bind();
+        fgSplashProgress("loading aircraft");
+
+
+    } else if ( idle_state == 5 ) {
+        idle_state++;
+        ////////////////////////////////////////////////////////////////////
+        // Initialize the 3D aircraft model subsystem (has a dependency on
+        // the scenery subsystem.)
+        ////////////////////////////////////////////////////////////////////
+        globals->set_aircraft_model(new FGAircraftModel);
+        globals->get_aircraft_model()->init();
+        globals->get_aircraft_model()->bind();
+
+        ////////////////////////////////////////////////////////////////////
+        // Initialize the view manager subsystem.
+        ////////////////////////////////////////////////////////////////////
+        FGViewMgr *viewmgr = new FGViewMgr;
+        globals->set_viewmgr( viewmgr );
+        viewmgr->init();
+        viewmgr->bind();
+        fgSplashProgress("generating sky elements");
+
+
+    } else if ( idle_state == 6 ) {
+        idle_state++;
+        // Initialize the sky
+        SGPath ephem_data_path( globals->get_fg_root() );
+        ephem_data_path.append( "Astro" );
+        SGEphemeris *ephem = new SGEphemeris( ephem_data_path.c_str() );
+        ephem->update( globals->get_time_params()->getMjd(),
+                       globals->get_time_params()->getLst(),
+                       0.0 );
+        globals->set_ephem( ephem );
+
+        // TODO: move to environment mgr
+        thesky = new SGSky;
+        SGPath texture_path(globals->get_fg_root());
+        texture_path.append("Textures");
+        texture_path.append("Sky");
+        for (int i = 0; i < FGEnvironmentMgr::MAX_CLOUD_LAYERS; i++) {
+            SGCloudLayer * layer = new SGCloudLayer(texture_path.str());
+            thesky->add_cloud_layer(layer);
+        }
+
+        SGPath sky_tex_path( globals->get_fg_root() );
+        sky_tex_path.append( "Textures" );
+        sky_tex_path.append( "Sky" );
+        thesky->texture_path( sky_tex_path.str() );
+
+        // The sun and moon diameters are scaled down numbers of the
+        // actual diameters. This was needed to fit bot the sun and the
+        // moon within the distance to the far clip plane.
+        // Moon diameter:    3,476 kilometers
+        // Sun diameter: 1,390,000 kilometers
+        thesky->build( 80000.0, 80000.0,
+                       463.3, 361.8,
+                       globals->get_ephem()->getNumPlanets(), 
+                       globals->get_ephem()->getPlanets(),
+                       globals->get_ephem()->getNumStars(),
+                       globals->get_ephem()->getStars() );
+
+        // Initialize MagVar model
+        SGMagVar *magvar = new SGMagVar();
+        globals->set_mag( magvar );
+
+
+                                    // kludge to initialize mag compass
+                                    // (should only be done for in-flight
+                                    // startup)
+        // update magvar model
+        globals->get_mag()->update( fgGetDouble("/position/longitude-deg")
+                                    * SGD_DEGREES_TO_RADIANS,
+                                    fgGetDouble("/position/latitude-deg")
+                                    * SGD_DEGREES_TO_RADIANS,
+                                    fgGetDouble("/position/altitude-ft")
+                                    * SG_FEET_TO_METER,
+                                    globals->get_time_params()->getJD() );
+        double var = globals->get_mag()->get_magvar() * SGD_RADIANS_TO_DEGREES;
+        fgSetDouble("/instrumentation/heading-indicator/offset-deg", -var);
+
+        // airport = new ssgBranch;
+        // airport->setName( "Airport Lighting" );
+        // lighting->addKid( airport );
+
+        // build our custom render states
+        globals->get_renderer()->build_states();
+        fgSplashProgress("initializing subsystems");
+
+
+    } else if ( idle_state == 7 ) {
+        idle_state++;
         // Initialize audio support
 #ifdef ENABLE_AUDIO_SUPPORT
 
@@ -614,8 +853,6 @@ static void fgIdleFunction ( void ) {
         }
 #endif
 
-        idle_state++;
-    } else if ( idle_state == 2 ) {
         // These are a few miscellaneous things that aren't really
         // "subsystems" but still need to be initialized.
 
@@ -625,8 +862,6 @@ static void fgIdleFunction ( void ) {
         }
 #endif
 
-        idle_state++;
-    } else if ( idle_state == 3 ) {
         // This is the top level init routine which calls all the
         // other subsystem initialization routines.  If you are adding
         // a subsystem to flightgear, its initialization call should
@@ -636,9 +871,11 @@ static void fgIdleFunction ( void ) {
                 "Subsystem initializations failed ..." );
             exit(-1);
         }
+        fgSplashProgress("setting up time & renderer");
 
-        idle_state++;
-    } else if ( idle_state == 4 ) {
+
+    } else if ( idle_state == 8 ) {
+        idle_state = 1000;
         // Initialize the time offset (warp) after fgInitSubsystem
         // (which initializes the lighting interpolation tables.)
         fgInitTimeOffset();
@@ -646,34 +883,19 @@ static void fgIdleFunction ( void ) {
         // setup OpenGL view parameters
         globals->get_renderer()->init();
 
-        // Read the list of available aircrafts
-        fgReadAircraft();
-
-        idle_state++;
-    } else if ( idle_state == 5 ) {
-
-        idle_state++;
-    } else if ( idle_state == 6 ) {
-        // sleep(1);
-
-        idle_state = 1000;
-
         SG_LOG( SG_GENERAL, SG_INFO, "Panel visible = " << fgPanelVisible() );
         globals->get_renderer()->resize( fgGetInt("/sim/startup/xsize"),
                                          fgGetInt("/sim/startup/ysize") );
 
-    } 
+        fgSplashProgress("loading scenery objects");
+
+    }
 
     if ( idle_state == 1000 ) {
         // We've finished all our initialization steps, from now on we
         // run the main loop.
-        fgSetBool("sim/sceneryloaded",false);
-
-        fgRegisterIdleHandler(fgMainLoop);
-    } else {
-        if ( fgGetBool("/sim/startup/splash-screen") ) {
-            fgSplashUpdate(0.0, 1.0);
-        }
+        fgSetBool("sim/sceneryloaded", false);
+        fgRegisterIdleHandler( fgMainLoop );
     }
 }
 
@@ -719,7 +941,7 @@ bool fgMainInit( int argc, char **argv ) {
     fgInitFGRoot(argc, argv);
 
     // Check for the correct base package version
-    static char required_version[] = "0.9.8";
+    static char required_version[] = "0.9.9";
     string base_version = fgBasePackageVersion();
     if ( !(base_version == required_version) ) {
         // tell the operator how to use this application
@@ -738,9 +960,6 @@ bool fgMainInit( int argc, char **argv ) {
 
     sgUseDisplayList = fgGetBool( "/sim/rendering/use-display-list", true );
 
-    // Initialize the Aircraft directory to "" (UIUC)
-    aircraft_dir = "";
-
     // Load the configuration parameters.  (Command line options
     // overrides config file options.  Config file options override
     // defaults.)
@@ -768,191 +987,21 @@ bool fgMainInit( int argc, char **argv ) {
     bool get_stencil_buffer = false;
 #endif
 
+    // Initialize plib net interface
+    netInit( &argc, argv );
+
     // Clouds3D requires an alpha channel
     // clouds may require stencil buffer
     fgOSOpenWindow( fgGetInt("/sim/startup/xsize"),
                     fgGetInt("/sim/startup/ysize"),
                     fgGetInt("/sim/rendering/bits-per-pixel"),
-                    fgGetBool("/sim/rendering/clouds3d"),
+                    fgGetBool("/sim/rendering/clouds3d-enable"),
                     get_stencil_buffer,
                     fgGetBool("/sim/startup/fullscreen") );
 
-    // This seems to be the absolute earliest in the init sequence
-    // that these calls will return valid info.  Too bad it's after
-    // we've already created and sized out window. :-(
-    general.set_glVendor( (char *)glGetString ( GL_VENDOR ) );
-    general.set_glRenderer( (char *)glGetString ( GL_RENDERER ) );
-    general.set_glVersion( (char *)glGetString ( GL_VERSION ) );
-    SG_LOG( SG_GENERAL, SG_INFO, general.get_glRenderer() );
-
-    GLint tmp;
-    glGetIntegerv( GL_MAX_TEXTURE_SIZE, &tmp );
-    general.set_glMaxTexSize( tmp );
-    SG_LOG ( SG_GENERAL, SG_INFO, "Max texture size = " << tmp );
-
-    glGetIntegerv( GL_DEPTH_BITS, &tmp );
-    general.set_glDepthBits( tmp );
-    SG_LOG ( SG_GENERAL, SG_INFO, "Depth buffer bits = " << tmp );
-
-    // Initialize plib net interface
-    netInit( &argc, argv );
-
-    // Initialize ssg (from plib).  Needs to come before we do any
-    // other ssg stuff, but after opengl has been initialized.
-    ssgInit();
-
-    // Initialize the user interface (we need to do this before
-    // passing off control to the OS main loop and before
-    // fgInitGeneral to get our fonts !!!
-    guiInit();
-
-    // Read the list of available aircrafts
-    fgReadAircraft();
-
-#ifdef GL_EXT_texture_lod_bias
-    glTexEnvf( GL_TEXTURE_FILTER_CONTROL_EXT, GL_TEXTURE_LOD_BIAS_EXT, -0.5 ) ;
-#endif
-
-            // get the address of our OpenGL extensions
-    if ( fgGetBool("/sim/rendering/distance-attenuation") )
-    {
-        if (SGIsOpenGLExtensionSupported("GL_EXT_point_parameters") ) {
-            glPointParameterIsSupported = true;
-            glPointParameterfPtr = (glPointParameterfProc)
-                                   SGLookupFunction("glPointParameterfEXT");
-            glPointParameterfvPtr = (glPointParameterfvProc)
-                                    SGLookupFunction("glPointParameterfvEXT");
-
-        } else if ( SGIsOpenGLExtensionSupported("GL_ARB_point_parameters") ) {
-            glPointParameterIsSupported = true;
-            glPointParameterfPtr = (glPointParameterfProc)
-                                   SGLookupFunction("glPointParameterfARB");
-            glPointParameterfvPtr = (glPointParameterfvProc)
-                                    SGLookupFunction("glPointParameterfvARB");
-        } else
-            glPointParameterIsSupported = false;
-   }
-
-    // based on the requested presets, calculate the true starting
-    // lon, lat
-    fgInitNav();
-    fgInitPosition();
-
-    SGTime *t = fgInitTime();
-    globals->set_time_params( t );
-
-    // Do some quick general initializations
-    if( !fgInitGeneral()) {
-        SG_LOG( SG_GENERAL, SG_ALERT, 
-            "General initializations failed ..." );
-        exit(-1);
-    }
-
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the property-based built-in commands
-    ////////////////////////////////////////////////////////////////////
-    fgInitCommands();
-
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the material manager
-    ////////////////////////////////////////////////////////////////////
-    globals->set_matlib( new SGMaterialLib );
-
-    globals->set_model_lib(new SGModelLib);
-
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the TG scenery subsystem.
-    ////////////////////////////////////////////////////////////////////
-    globals->set_scenery( new FGScenery );
-    globals->get_scenery()->init();
-    globals->get_scenery()->bind();
-    globals->set_tile_mgr( new FGTileMgr );
-
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the general model subsystem.
-    ////////////////////////////////////////////////////////////////////
-    globals->set_model_mgr(new FGModelMgr);
-    globals->get_model_mgr()->init();
-    globals->get_model_mgr()->bind();
-
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the 3D aircraft model subsystem (has a dependency on
-    // the scenery subsystem.)
-    ////////////////////////////////////////////////////////////////////
-    globals->set_aircraft_model(new FGAircraftModel);
-    globals->get_aircraft_model()->init();
-    globals->get_aircraft_model()->bind();
-
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the view manager subsystem.
-    ////////////////////////////////////////////////////////////////////
-    FGViewMgr *viewmgr = new FGViewMgr;
-    globals->set_viewmgr( viewmgr );
-    viewmgr->init();
-    viewmgr->bind();
-
-
-    // Initialize the sky
-    SGPath ephem_data_path( globals->get_fg_root() );
-    ephem_data_path.append( "Astro" );
-    SGEphemeris *ephem = new SGEphemeris( ephem_data_path.c_str() );
-    ephem->update( globals->get_time_params()->getMjd(),
-                   globals->get_time_params()->getLst(),
-                   0.0 );
-    globals->set_ephem( ephem );
-
-    // TODO: move to environment mgr
-    thesky = new SGSky;
-    SGPath texture_path(globals->get_fg_root());
-    texture_path.append("Textures");
-    texture_path.append("Sky");
-    for (int i = 0; i < FGEnvironmentMgr::MAX_CLOUD_LAYERS; i++) {
-        SGCloudLayer * layer = new SGCloudLayer(texture_path.str());
-        thesky->add_cloud_layer(layer);
-    }
-
-    SGPath sky_tex_path( globals->get_fg_root() );
-    sky_tex_path.append( "Textures" );
-    sky_tex_path.append( "Sky" );
-    thesky->texture_path( sky_tex_path.str() );
-
-    // The sun and moon diameters are scaled down numbers of the
-    // actual diameters. This was needed to fit bot the sun and the
-    // moon within the distance to the far clip plane.
-    // Moon diameter:    3,476 kilometers
-    // Sun diameter: 1,390,000 kilometers
-    thesky->build( 80000.0, 80000.0,
-                   463.3, 361.8,
-                   globals->get_ephem()->getNumPlanets(), 
-                   globals->get_ephem()->getPlanets(),
-                   globals->get_ephem()->getNumStars(),
-                   globals->get_ephem()->getStars() );
-
-    // Initialize MagVar model
-    SGMagVar *magvar = new SGMagVar();
-    globals->set_mag( magvar );
-
-
-                                // kludge to initialize mag compass
-                                // (should only be done for in-flight
-                                // startup)
-    // update magvar model
-    globals->get_mag()->update( fgGetDouble("/position/longitude-deg")
-                                * SGD_DEGREES_TO_RADIANS,
-                                fgGetDouble("/position/latitude-deg")
-                                * SGD_DEGREES_TO_RADIANS,
-                                fgGetDouble("/position/altitude-ft")
-                                * SG_FEET_TO_METER,
-                                globals->get_time_params()->getJD() );
-    double var = globals->get_mag()->get_magvar() * SGD_RADIANS_TO_DEGREES;
-    fgSetDouble("/instrumentation/heading-indicator/offset-deg", -var);
-
-    // airport = new ssgBranch;
-    // airport->setName( "Airport Lighting" );
-    // lighting->addKid( airport );
-
-    // build our custom render states
-    globals->get_renderer()->build_states();
+    // Initialize the splash screen right away
+    fntInit();
+    fgSplashInit(fgGetString("/sim/startup/splash-texture"));
 
     // pass control off to the master event handler
     fgOSMainLoop();
@@ -963,4 +1012,3 @@ bool fgMainInit( int argc, char **argv ) {
 }
 
 
-// end of main.cxx
