@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: ATC-Outputs.cxx,v 1.4 2005/01/04 22:45:08 curt Exp $
+// $Id: ATC-Outputs.cxx,v 1.7 2005/03/08 19:47:51 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -31,11 +31,17 @@
 #  include <sys/types.h>
 #  include <sys/stat.h>
 #  include <fcntl.h>
+#  include <unistd.h>
+#  include <ostream>
 #endif
 
+#include <errno.h>
+#include <math.h>
+
 #include STL_STRING
 
 #include <simgear/debug/logstream.hxx>
+#include <simgear/misc/sg_path.hxx>
 
 #include <Main/fg_props.hxx>
 
@@ -267,6 +273,7 @@ bool FGATCOutput::open( int lock_fd ) {
 
 #endif
 
+#ifdef ATCFLIGHTSIM_HAVE_COMPASS
     /////////////////////////////////////////////////////////////////////
     // Home the compass stepper motor
     /////////////////////////////////////////////////////////////////////
@@ -317,6 +324,7 @@ bool FGATCOutput::open( int lock_fd ) {
     }
 
     compass_position = 0.0;
+#endif
 
     /////////////////////////////////////////////////////////////////////
     // Blank the radio display
@@ -380,7 +388,6 @@ bool FGATCOutput::open( int lock_fd ) {
 /////////////////////////////////////////////////////////////////////
 
 bool FGATCOutput::do_lamps() {
-
     if ( lamps_out_node != NULL ) {
         for ( int i = 0; i < lamps_out_node->nChildren(); ++i ) {
             // read the next config entry from the property tree
@@ -930,7 +937,9 @@ bool FGATCOutput::process() {
 
     do_lamps();
     do_radio_display();
+#ifdef ATCFLIGHTSIM_HAVE_COMPASS
     do_steppers();
+#endif
 	
     return true;
 }
