@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: native_ctrls.cxx,v 1.25 2005/01/03 03:20:31 curt Exp $
+// $Id: native_ctrls.cxx,v 1.31 2005/08/23 21:38:49 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -111,8 +111,10 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
     net->version = FG_NET_CTRLS_VERSION;
     net->aileron = node->getDoubleValue( "aileron" );
     net->elevator = node->getDoubleValue( "elevator" );
-    net->elevator_trim = node->getDoubleValue( "elevator-trim" );
     net->rudder = node->getDoubleValue( "rudder" );
+    net->aileron_trim = node->getDoubleValue( "aileron-trim" );
+    net->elevator_trim = node->getDoubleValue( "elevator-trim" );
+    net->rudder_trim = node->getDoubleValue( "rudder-trim" );
     net->flaps = node->getDoubleValue( "flaps" );
     net->flaps_power
         = fgGetDouble( "/systems/electrical/outputs/flaps", 1.0 ) >= 1.0;
@@ -153,7 +155,7 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
         if ( fuelpump != NULL ) {
             net->fuel_pump_power[i] = ( fuelpump->getDoubleValue() >= 1.0 );
         } else {
-            net->fuel_pump_power[i] = 0.0;
+            net->fuel_pump_power[i] = 0;
         }
 
 	// Faults
@@ -189,12 +191,9 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
         = node->getChild("copilot-brake-right")->getDoubleValue();
     net->brake_parking = node->getChild("brake-parking")->getDoubleValue();
 
-    net->gear_handle = fgGetBool( "controls/gear/gear-down" );
+    net->gear_handle = fgGetBool( "/controls/gear/gear-down" );
 
-    tempnode = node->getChild("master-avionics");
-    if ( tempnode != NULL ) {
-        net->master_avionics = tempnode->getBoolValue();
-    }
+    net->master_avionics = fgGetBool("/controls/switches/master-avionics");
 
     net->wind_speed_kt = fgGetDouble("/environment/wind-speed-kt");
     net->wind_dir_deg = fgGetDouble("/environment/wind-from-heading-deg");
@@ -212,7 +211,7 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
     net->hground = cur_fdm_state->get_ground_elev_ft() * SG_FEET_TO_METER;
     net->magvar = fgGetDouble("/environment/magnetic-variation-deg");
 
-    net->icing = fgGetDouble("/hazards/icing/wing");
+    net->icing = fgGetBool("/hazards/icing/wing");
 
     net->speedup = fgGetInt("/sim/speed-up");
     net->freeze = 0;
@@ -233,11 +232,15 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
         net->version = htonl(net->version);
         htond(net->aileron);
         htond(net->elevator);
-        htond(net->elevator_trim);
         htond(net->rudder);
+        htond(net->aileron_trim);
+        htond(net->elevator_trim);
+        htond(net->rudder_trim);
         htond(net->flaps);
         net->flaps_power = htonl(net->flaps_power);
         net->flap_motor_ok = htonl(net->flap_motor_ok);
+
+        net->num_engines = htonl(net->num_engines);
         for ( i = 0; i < FGNetCtrls::FG_MAX_ENGINES; ++i ) {
             net->master_bat[i] = htonl(net->master_bat[i]);
             net->master_alt[i] = htonl(net->master_alt[i]);
@@ -248,18 +251,20 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
             net->fuel_pump_power[i] = htonl(net->fuel_pump_power[i]);
             htond(net->prop_advance[i]);
             htond(net->condition[i]);
-	    net->engine_ok[i] = htonl(net->engine_ok[i]);
-	    net->mag_left_ok[i] = htonl(net->mag_left_ok[i]);
-	    net->mag_right_ok[i] = htonl(net->mag_right_ok[i]);
-	    net->spark_plugs_ok[i] = htonl(net->spark_plugs_ok[i]);
-	    net->oil_press_status[i] = htonl(net->oil_press_status[i]);
-	    net->fuel_pump_ok[i] = htonl(net->fuel_pump_ok[i]);
+            net->engine_ok[i] = htonl(net->engine_ok[i]);
+            net->mag_left_ok[i] = htonl(net->mag_left_ok[i]);
+            net->mag_right_ok[i] = htonl(net->mag_right_ok[i]);
+            net->spark_plugs_ok[i] = htonl(net->spark_plugs_ok[i]);
+            net->oil_press_status[i] = htonl(net->oil_press_status[i]);
+            net->fuel_pump_ok[i] = htonl(net->fuel_pump_ok[i]);
         }
-        net->num_engines = htonl(net->num_engines);
+
+        net->num_tanks = htonl(net->num_tanks);
         for ( i = 0; i < FGNetCtrls::FG_MAX_TANKS; ++i ) {
             net->fuel_selector[i] = htonl(net->fuel_selector[i]);
         }
-        net->num_tanks = htonl(net->num_tanks);
+
+        net->cross_feed = htonl(net->cross_feed);
         htond(net->brake_left);
         htond(net->brake_right);
         htond(net->copilot_brake_left);
@@ -294,13 +299,16 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
         net->version = htonl(net->version);
         htond(net->aileron);
         htond(net->elevator);
-        htond(net->elevator_trim);
         htond(net->rudder);
+        htond(net->aileron_trim);
+        htond(net->elevator_trim);
+        htond(net->rudder_trim);
         htond(net->flaps);
         net->flaps_power = htonl(net->flaps_power);
         net->flap_motor_ok = htonl(net->flap_motor_ok);
+
         net->num_engines = htonl(net->num_engines);
-        for ( i = 0; i < net->num_engines; ++i ) {
+        for ( i = 0; i < (int)net->num_engines; ++i ) {
             net->master_bat[i] = htonl(net->master_bat[i]);
             net->master_alt[i] = htonl(net->master_alt[i]);
             net->magnetos[i] = htonl(net->magnetos[i]);
@@ -310,17 +318,20 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
             net->fuel_pump_power[i] = htonl(net->fuel_pump_power[i]);
             htond(net->prop_advance[i]);
             htond(net->condition[i]);
-	    net->engine_ok[i] = htonl(net->engine_ok[i]);
-	    net->mag_left_ok[i] = htonl(net->mag_left_ok[i]);
-	    net->mag_right_ok[i] = htonl(net->mag_right_ok[i]);
-	    net->spark_plugs_ok[i] = htonl(net->spark_plugs_ok[i]);
-	    net->oil_press_status[i] = htonl(net->oil_press_status[i]);
-	    net->fuel_pump_ok[i] = htonl(net->fuel_pump_ok[i]);
+            net->engine_ok[i] = htonl(net->engine_ok[i]);
+            net->mag_left_ok[i] = htonl(net->mag_left_ok[i]);
+            net->mag_right_ok[i] = htonl(net->mag_right_ok[i]);
+            net->spark_plugs_ok[i] = htonl(net->spark_plugs_ok[i]);
+            net->oil_press_status[i] = htonl(net->oil_press_status[i]);
+            net->fuel_pump_ok[i] = htonl(net->fuel_pump_ok[i]);
         }
+
         net->num_tanks = htonl(net->num_tanks);
-        for ( i = 0; i < net->num_tanks; ++i ) {
+        for ( i = 0; i < FGNetCtrls::FG_MAX_TANKS; ++i ) {
             net->fuel_selector[i] = htonl(net->fuel_selector[i]);
         }
+
+        net->cross_feed = htonl(net->cross_feed);
         htond(net->brake_left);
         htond(net->brake_right);
         htond(net->copilot_brake_left);
@@ -350,8 +361,10 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
     node = fgGetNode("/controls/flight", true);
     node->setDoubleValue( "aileron", net->aileron );
     node->setDoubleValue( "elevator", net->elevator );
-    node->setDoubleValue( "elevator-trim", net->elevator_trim );
     node->setDoubleValue( "rudder", net->rudder );
+    node->setDoubleValue( "aileron-trim", net->aileron_trim );
+    node->setDoubleValue( "elevator-trim", net->elevator_trim );
+    node->setDoubleValue( "rudder-trim", net->rudder_trim );
     node->setDoubleValue( "flaps", net->flaps );
     fgSetBool( "/systems/electrical/outputs/flaps", net->flaps_power );
     node->setBoolValue( "flaps-serviceable", net->flap_motor_ok );
