@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: native_fdm.cxx,v 1.25 2005/01/05 03:43:05 curt Exp $
+// $Id: native_fdm.cxx,v 1.29 2005/08/14 12:57:13 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -120,7 +120,7 @@ bool FGNativeFDM::open() {
 
 
 void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
-    int i;
+    unsigned int i;
 
     // Version sanity checking
     net->version = FG_NET_FDM_VERSION;
@@ -191,7 +191,7 @@ void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
     net->num_wheels = FGNetFDM::FG_MAX_WHEELS;
     for (i = 0; i < net->num_wheels; ++i ) {
         SGPropertyNode *node = fgGetNode("/gear/gear", i, true);
-        net->wow[i] = node->getDoubleValue("wow");
+        net->wow[i] = node->getIntValue("wow");
         net->gear_pos[i] = node->getDoubleValue("position-norm");
         net->gear_steer[i] = node->getDoubleValue("steering-norm");
         net->gear_compression[i] = node->getDoubleValue("compression-norm");
@@ -295,7 +295,7 @@ void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
 
 
 void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
-    int i;
+    unsigned int i;
 
     if ( net_byte_order ) {
         // Convert to the net buffer from network format
@@ -356,7 +356,7 @@ void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
             htonf(net->gear_compression[i]);
         }
 
-        net->cur_time = ntohl(net->cur_time);
+        net->cur_time = htonl(net->cur_time);
         net->warp = ntohl(net->warp);
         htonf(net->visibility);
 
@@ -383,8 +383,8 @@ void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
 	if ( net->agl > -9000 ) {
 	    cur_fdm_state->_set_Altitude_AGL( net->agl * SG_METER_TO_FEET );
 	} else {
-	    double agl_m
-	      = net->altitude - globals->get_scenery()->get_cur_elev();
+	    double agl_m = net->altitude
+              - cur_fdm_state->get_Runway_altitude_m();
 	    cur_fdm_state->_set_Altitude_AGL( agl_m * SG_METER_TO_FEET );
 	}
         cur_fdm_state->_set_Euler_Angles( net->phi,
