@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: native_gui.cxx,v 1.15 2004/12/30 20:48:54 curt Exp $
+// $Id: native_gui.cxx,v 1.18 2005/08/14 12:57:13 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -136,7 +136,7 @@ void FGProps2NetGUI( FGNetGUI *net ) {
 	= fgGetNode("/instrumentation/nav/radials/reciprocal-radial-deg", true);
     static SGPropertyNode *nav_gs_deflection
 	= fgGetNode("/instrumentation/nav/gs-needle-deflection", true);
-    int i;
+    unsigned int i;
 
     // Version sanity checking
     net->version = FG_NET_GUI_VERSION;
@@ -163,7 +163,7 @@ void FGProps2NetGUI( FGNetGUI *net ) {
     // Environment
     net->cur_time = globals->get_time_params()->get_cur_time();
     net->warp = globals->get_warp();
-    net->ground_elev = globals->get_scenery()->get_cur_elev();
+    net->ground_elev = cur_fdm_state->get_Runway_altitude_m();
 
     // Approach
     net->tuned_freq = nav_freq->getDoubleValue();
@@ -237,7 +237,7 @@ void FGProps2NetGUI( FGNetGUI *net ) {
 
     htonf(net->tuned_freq);
     htonf(net->nav_radial);
-    net->in_range = htonl(net->in_range);
+    net->in_range = htonl( net->in_range );
     htonf(net->dist_nm);
     htonf(net->course_deviation_deg);
     htonf(net->gs_deviation_deg);
@@ -246,7 +246,7 @@ void FGProps2NetGUI( FGNetGUI *net ) {
 
 
 void FGNetGUI2Props( FGNetGUI *net ) {
-    int i;
+    unsigned int i;
 
 #if defined( FG_USE_NETWORK_BYTE_ORDER )
     // Convert to the net buffer from network format
@@ -271,7 +271,8 @@ void FGNetGUI2Props( FGNetGUI *net ) {
     net->ground_elev = htonl( net->ground_elev );
 
     htonf(net->tuned_freq);
-    net->in_range = htonl(net->in_range);
+    htonf(net->nav_radial);
+    net->in_range = htonl( net->in_range );
     htonf(net->dist_nm);
     htonf(net->course_deviation_deg);
     htonf(net->gs_deviation_deg);
@@ -303,7 +304,6 @@ void FGNetGUI2Props( FGNetGUI *net ) {
 	}
 
         globals->set_warp( net->warp );
-        globals->get_scenery()->set_cur_elev( net->ground_elev );
 
         // Approach
         fgSetDouble( "/instrumentation/nav[0]/frequencies/selected-mhz",
