@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: ray.cxx,v 1.1.1.1 2002/09/10 01:14:06 curt Exp $
+// $Id: ray.cxx,v 1.2 2005/10/25 13:49:57 ehofman Exp $
 
 
 #include <simgear/constants.h>
@@ -104,11 +104,11 @@ bool FGRAY::gen_message() {
 	/* Make sure the angles are reasonable onscale */
  	/* We use an asymmetric mapping so that the chair behaves
  	   reasonably when upside down.  Otherwise it oscillates. */
- 	while ( ang_pos < -2*SGD_PI/3 ) {
-		ang_pos += 2 * SGD_PI;
+ 	while ( ang_pos < -SGD_2PI/3 ) {
+		ang_pos += SGD_2PI;
 	}
- 	while ( ang_pos >  4*SGD_PI/3 ) {
-		ang_pos -= 2 * SGD_PI;
+ 	while ( ang_pos >  2*SGD_2PI/3 ) {
+		ang_pos -= SGD_2PI;
 	}
 
 	/* Tell interested parties what the situation is */
@@ -134,8 +134,8 @@ bool FGRAY::gen_message() {
 		if ( fabs ( ang_pos - chair_heading ) > SGD_PI )
 		{	/* Need to swing chair by 360 degrees */
 			if ( ang_pos < chair_heading )
-				chair_heading -= 2 * SGD_PI;
-			else	chair_heading += 2 * SGD_PI;
+				chair_heading -= SGD_2PI;
+			else	chair_heading +=  SGD_2PI;
 		}
 		/* Remove the chair heading from the true heading */
 		ang_pos -= chair_heading;
@@ -144,7 +144,7 @@ bool FGRAY::gen_message() {
  		   can just about represent 30 degrees full scale.  */
 		chair_heading += ang_pos * dt * 0.2;
 		/* If they turn fast, at 90 deg error subtract 30 deg */
-		if ( fabs(ang_pos) > SGD_PI / 2 )
+		if ( fabs(ang_pos) > SGD_PI_2 )
 			chair_heading += ang_pos / 3;
 
 	} else
@@ -178,8 +178,8 @@ bool FGRAY::gen_message() {
 		/* Scale to the hardware's full scale range */
 		propose /= fullscale [ subaxis ];
 		/* Use a sine shaped washout on all axes */
-		if ( propose < -SGD_PI / 2 ) *dac = 0x0000; else
-		if ( propose >  SGD_PI / 2 ) *dac = 0xFFFF; else
+		if ( propose < -SGD_PI_2 ) *dac = 0x0000; else
+		if ( propose >  SGD_PI_2 ) *dac = 0xFFFF; else
 		   *dac = (unsigned short) ( 32767 * 
 				( 1.0 + sin ( propose ) ) );
 	}
