@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: beacon.cxx,v 1.7 2004/11/19 22:10:44 curt Exp $
+// $Id: beacon.cxx,v 1.8 2005/11/12 12:31:11 ehofman Exp $
 
 
 #include "beacon.hxx"
@@ -62,7 +62,7 @@ bool FGBeacon::init() {
 	ptr += INNER_DIT_LEN;
     }
 
-    inner = new SGSoundSample( inner_buf, INNER_SIZE, BYTES_PER_SECOND, false );
+    inner = new SGSoundSample( inner_buf, INNER_SIZE, BYTES_PER_SECOND );
     inner->set_reference_dist( 10.0 );
     inner->set_max_dist( 20.0 );
 
@@ -82,8 +82,7 @@ bool FGBeacon::init() {
     ptr += MIDDLE_DIT_LEN;
     memcpy( ptr, middle_dah, MIDDLE_DAH_LEN );
 
-    middle = new SGSoundSample( middle_buf, MIDDLE_SIZE, BYTES_PER_SECOND,
-                                false );
+    middle = new SGSoundSample( middle_buf, MIDDLE_SIZE, BYTES_PER_SECOND );
     middle->set_reference_dist( 10.0 );
     middle->set_max_dist( 20.0 );
 
@@ -98,7 +97,7 @@ bool FGBeacon::init() {
     ptr += OUTER_DAH_LEN;
     memcpy( ptr, outer_dah, OUTER_DAH_LEN );
 
-    outer = new SGSoundSample( outer_buf, OUTER_SIZE, BYTES_PER_SECOND, false );
+    outer = new SGSoundSample( outer_buf, OUTER_SIZE, BYTES_PER_SECOND);
     outer->set_reference_dist( 10.0 );
     outer->set_max_dist( 20.0 );
 
