@@ -19,7 +19,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: light.cxx,v 1.45 2004/11/19 22:10:45 curt Exp $
+// $Id: light.cxx,v 1.50 2005/11/11 14:46:15 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -44,9 +44,6 @@
 #  include <math.h>
 #endif
 
-#include <string>
-SG_USING_STD(string);
-
 #include <simgear/constants.h>
 #include <simgear/debug/logstream.hxx>
 #include <simgear/math/interpolater.hxx>
@@ -58,10 +55,11 @@ SG_USING_STD(string);
 #include <Main/main.hxx>
 #include <Main/globals.hxx>
 #include <Main/fg_props.hxx>
+#include <Main/renderer.hxx>
 #include <Main/viewer.hxx>
 
 #include "light.hxx"
-#include "sunpos.hxx"
+#include "tmp.hxx"
 
 
 // Constructor
@@ -126,7 +124,6 @@ void FGLight::reinit () {
     init();
 
     fgUpdateSunPos();
-    fgUpdateMoonPos();
 
     update_sky_color();
     update_adj_fog_color();
@@ -150,7 +147,6 @@ void FGLight::update( double dt ) {
     if (_dt_total >= 0.5) {
         _dt_total -= 0.5;
         fgUpdateSunPos();
-        fgUpdateMoonPos();
     }
 
     update_adj_fog_color();
@@ -167,20 +163,20 @@ void FGLight::update_sky_color () {
     const GLfloat base_sky_color[4] = { 0.31, 0.43, 0.69, 1.0 };
     const GLfloat base_fog_color[4] = { 0.84, 0.87, 1.0,  1.0 };
 
-    SG_LOG( SG_EVENT, SG_INFO, "Updating light parameters." );
+    SG_LOG( SG_EVENT, SG_DEBUG, "Updating light parameters." );
 
     // calculate lighting parameters based on sun's relative angle to
     // local up
 
     float deg = _sun_angle * SGD_RADIANS_TO_DEGREES;
-    SG_LOG( SG_EVENT, SG_INFO, "  Sun angle = " << deg );
+    SG_LOG( SG_EVENT, SG_DEBUG, "  Sun angle = " << deg );
 
     float ambient = _ambient_tbl->interpolate( deg );
     float diffuse = _diffuse_tbl->interpolate( deg );
     float specular = _specular_tbl->interpolate( deg );
     float sky_brightness = _sky_tbl->interpolate( deg );
 
-    SG_LOG( SG_EVENT, SG_INFO, 
+    SG_LOG( SG_EVENT, SG_DEBUG,
 	    "  ambient = " << ambient << "  diffuse = " << diffuse 
 	    << "  specular = " << specular << "  sky = " << sky_brightness );
 
